/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ScreenBrightness.Display.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "screenbrightnessdisplayadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ScreenBrightnessDisplayAdaptor
 */

ScreenBrightnessDisplayAdaptor::ScreenBrightnessDisplayAdaptor(PowerDevil::ScreenBrightnessDisplay *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ScreenBrightnessDisplayAdaptor::~ScreenBrightnessDisplayAdaptor()
{
    // destructor
}

int ScreenBrightnessDisplayAdaptor::brightness() const
{
    // get the value of property Brightness
    return qvariant_cast< int >(parent()->property("Brightness"));
}

bool ScreenBrightnessDisplayAdaptor::isInternal() const
{
    // get the value of property IsInternal
    return qvariant_cast< bool >(parent()->property("IsInternal"));
}

QString ScreenBrightnessDisplayAdaptor::label() const
{
    // get the value of property Label
    return qvariant_cast< QString >(parent()->property("Label"));
}

int ScreenBrightnessDisplayAdaptor::maxBrightness() const
{
    // get the value of property MaxBrightness
    return qvariant_cast< int >(parent()->property("MaxBrightness"));
}

void ScreenBrightnessDisplayAdaptor::SetBrightness(int brightness, uint flags)
{
    // handle method call org.kde.ScreenBrightness.Display.SetBrightness
    parent()->SetBrightness(brightness, flags);
}

void ScreenBrightnessDisplayAdaptor::SetBrightnessWithContext(int brightness, uint flags, const QString &source_client_context)
{
    // handle method call org.kde.ScreenBrightness.Display.SetBrightnessWithContext
    parent()->SetBrightnessWithContext(brightness, flags, source_client_context);
}


#include "moc_screenbrightnessdisplayadaptor.cpp"
