/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Solid.PowerManagement.Actions.SuspendSession.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SUSPENDSESSIONADAPTOR_H
#define SUSPENDSESSIONADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "suspendsession.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Solid.PowerManagement.Actions.SuspendSession
 */
class SuspendSessionAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Solid.PowerManagement.Actions.SuspendSession")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Solid.PowerManagement.Actions.SuspendSession\">\n"
"    <method name=\"suspendToRam\"/>\n"
"    <method name=\"suspendToDisk\"/>\n"
"    <method name=\"suspendHybrid\"/>\n"
"    <signal name=\"aboutToSuspend\"/>\n"
"    <signal name=\"resumingFromSuspend\"/>\n"
"  </interface>\n"
        "")
public:
    SuspendSessionAdaptor(PowerDevil::BundledActions::SuspendSession *parent);
    ~SuspendSessionAdaptor() override;

    inline PowerDevil::BundledActions::SuspendSession *parent() const
    { return static_cast<PowerDevil::BundledActions::SuspendSession *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void suspendHybrid();
    void suspendToDisk();
    void suspendToRam();
Q_SIGNALS: // SIGNALS
    void aboutToSuspend();
    void resumingFromSuspend();
};

#endif
