/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<darkmodecontrol.h>)
#  include <darkmodecontrol.h>
#endif
#if __has_include(<keyboardbrightnesscontrol.h>)
#  include <keyboardbrightnesscontrol.h>
#endif
#if __has_include(<keyboardcolorcontrol.h>)
#  include <keyboardcolorcontrol.h>
#endif
#if __has_include(<nightlightinhibitor.h>)
#  include <nightlightinhibitor.h>
#endif
#if __has_include(<screenbrightnesscontrol.h>)
#  include <screenbrightnesscontrol.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_plasma_private_brightnesscontrolplugin()
{
    qmlRegisterModule("org.kde.plasma.private.brightnesscontrolplugin", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<DarkModeControl>("org.kde.plasma.private.brightnesscontrolplugin", 254);
    qmlRegisterTypesAndRevisions<KeyboardBrightnessControl>("org.kde.plasma.private.brightnesscontrolplugin", 254);
    qmlRegisterTypesAndRevisions<KeyboardColorControl>("org.kde.plasma.private.brightnesscontrolplugin", 254);
    qmlRegisterTypesAndRevisions<NightLightInhibitor>("org.kde.plasma.private.brightnesscontrolplugin", 254);
    qmlRegisterEnum<NightLightInhibitor::State>("NightLightInhibitor::State");
    qmlRegisterTypesAndRevisions<ScreenBrightnessControl>("org.kde.plasma.private.brightnesscontrolplugin", 254);
    qmlRegisterEnum<ScreenBrightnessControl::StepAction>("ScreenBrightnessControl::StepAction");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.plasma.private.brightnesscontrolplugin", 254, 254);
}

static const QQmlModuleRegistration orgkdeplasmaprivatebrightnesscontrolpluginRegistration("org.kde.plasma.private.brightnesscontrolplugin", qml_register_types_org_kde_plasma_private_brightnesscontrolplugin);
