/****************************************************************************
** Meta object code from reading C++ file 'inhibitioncontrol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../powerdevil-6.6.91/applets/batterymonitor/plugin/inhibitioncontrol.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'inhibitioncontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19RequestedInhibitionE_t {};
} // unnamed namespace

template <> constexpr inline auto RequestedInhibition::qt_create_metaobjectdata<qt_meta_tag_ZN19RequestedInhibitionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RequestedInhibition",
        "appName",
        "prettyName",
        "icon",
        "reason",
        "behaviors",
        "active",
        "allowed"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'appName'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'prettyName'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'icon'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'reason'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'behaviors'
        QtMocHelpers::PropertyData<QStringList>(5, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'active'
        QtMocHelpers::PropertyData<bool>(6, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
        // property 'allowed'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RequestedInhibition, qt_meta_tag_ZN19RequestedInhibitionE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RequestedInhibition::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19RequestedInhibitionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19RequestedInhibitionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19RequestedInhibitionE_t>.metaTypes,
    nullptr
} };

void RequestedInhibition::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<RequestedInhibition *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->appName; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->prettyName; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->icon; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->reason; break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->behaviors; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->active; break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->allowed; break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17InhibitionControlE_t {};
} // unnamed namespace

template <> constexpr inline auto InhibitionControl::qt_create_metaobjectdata<qt_meta_tag_ZN17InhibitionControlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "InhibitionControl",
        "QML.Element",
        "auto",
        "requestedInhibitionsChanged",
        "",
        "QList<RequestedInhibition>",
        "inhibitions",
        "hasInhibitionChanged",
        "status",
        "isLidPresentChanged",
        "triggersLidActionChanged",
        "isManuallyInhibitedChanged",
        "isManuallyInhibitedErrorChanged",
        "onServiceRegistered",
        "serviceName",
        "onServiceUnregistered",
        "onPolicyAgentPropertiesChanged",
        "ifaceName",
        "QVariantMap",
        "changedProps",
        "invalidatedProps",
        "onHasInhibitionChanged",
        "onIsManuallyInhibitedChanged",
        "onisManuallyInhibitedErrorChanged",
        "inhibit",
        "reason",
        "uninhibit",
        "setInhibitionAllowed",
        "appName",
        "allowed",
        "requestedInhibitions",
        "hasInhibition",
        "isLidPresent",
        "triggersLidAction",
        "isManuallyInhibited",
        "isManuallyInhibitedError",
        "isSilent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestedInhibitionsChanged'
        QtMocHelpers::SignalData<void(const QList<RequestedInhibition> &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'hasInhibitionChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'isLidPresentChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'triggersLidActionChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'isManuallyInhibitedChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'isManuallyInhibitedErrorChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'onServiceRegistered'
        QtMocHelpers::SlotData<void(const QString &)>(13, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'onServiceUnregistered'
        QtMocHelpers::SlotData<void(const QString &)>(15, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'onPolicyAgentPropertiesChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, const QStringList &)>(16, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { 0x80000000 | 18, 19 }, { QMetaType::QStringList, 20 },
        }}),
        // Slot 'onHasInhibitionChanged'
        QtMocHelpers::SlotData<void(bool)>(21, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'onIsManuallyInhibitedChanged'
        QtMocHelpers::SlotData<void(bool)>(22, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'onisManuallyInhibitedErrorChanged'
        QtMocHelpers::SlotData<void(bool)>(23, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Method 'inhibit'
        QtMocHelpers::MethodData<void(const QString &)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Method 'uninhibit'
        QtMocHelpers::MethodData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'setInhibitionAllowed'
        QtMocHelpers::MethodData<void(const QString &, const QString &, bool)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 25 }, { QMetaType::Bool, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'requestedInhibitions'
        QtMocHelpers::PropertyData<QList<RequestedInhibition>>(30, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 0),
        // property 'hasInhibition'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'isLidPresent'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 2),
        // property 'triggersLidAction'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 3),
        // property 'isManuallyInhibited'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 4),
        // property 'isManuallyInhibitedError'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Bindable, 5),
        // property 'isSilent'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<InhibitionControl, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject InhibitionControl::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17InhibitionControlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17InhibitionControlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17InhibitionControlE_t>.metaTypes,
    nullptr
} };

void InhibitionControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<InhibitionControl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestedInhibitionsChanged((*reinterpret_cast<std::add_pointer_t<QList<RequestedInhibition>>>(_a[1]))); break;
        case 1: _t->hasInhibitionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->isLidPresentChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->triggersLidActionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->isManuallyInhibitedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->isManuallyInhibitedErrorChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->onServiceRegistered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->onServiceUnregistered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->onPolicyAgentPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 9: _t->onHasInhibitionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->onIsManuallyInhibitedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->onisManuallyInhibitedErrorChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->inhibit((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->uninhibit(); break;
        case 14: _t->setInhibitionAllowed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (InhibitionControl::*)(const QList<RequestedInhibition> & )>(_a, &InhibitionControl::requestedInhibitionsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (InhibitionControl::*)(bool )>(_a, &InhibitionControl::hasInhibitionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (InhibitionControl::*)(bool )>(_a, &InhibitionControl::isLidPresentChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (InhibitionControl::*)(bool )>(_a, &InhibitionControl::triggersLidActionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (InhibitionControl::*)(bool )>(_a, &InhibitionControl::isManuallyInhibitedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (InhibitionControl::*)(bool )>(_a, &InhibitionControl::isManuallyInhibitedErrorChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<RequestedInhibition>*>(_v) = _t->bindableRequestedInhibitions().value(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->bindableHasInhibition().value(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->bindableIsLidPresent().value(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->bindableTriggersLidAction().value(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->bindableIsManuallyInhibited().value(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->bindableIsManuallyInhibitedError().value(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isSilent(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: {
            _t->bindableIsManuallyInhibitedError().setValue(*reinterpret_cast<bool*>(_v));
            break;
        }
        case 6: _t->setIsSilent(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableRequestedInhibitions(); break;
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableHasInhibition(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableIsLidPresent(); break;
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableTriggersLidAction(); break;
        case 4: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableIsManuallyInhibited(); break;
        case 5: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableIsManuallyInhibitedError(); break;
        default: break;
        }
    }
}

const QMetaObject *InhibitionControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *InhibitionControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17InhibitionControlE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int InhibitionControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void InhibitionControl::requestedInhibitionsChanged(const QList<RequestedInhibition> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void InhibitionControl::hasInhibitionChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void InhibitionControl::isLidPresentChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void InhibitionControl::triggersLidActionChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void InhibitionControl::isManuallyInhibitedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void InhibitionControl::isManuallyInhibitedErrorChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
