/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Solid.PowerManagement.Actions.PowerProfile.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "powerprofileadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class PowerProfileAdaptor
 */

PowerProfileAdaptor::PowerProfileAdaptor(PowerDevil::BundledActions::PowerProfile *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

PowerProfileAdaptor::~PowerProfileAdaptor()
{
    // destructor
}

QString PowerProfileAdaptor::configuredProfile()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.PowerProfile.configuredProfile
    return parent()->configuredProfile();
}

QString PowerProfileAdaptor::currentProfile()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.PowerProfile.currentProfile
    return parent()->currentProfile();
}

uint PowerProfileAdaptor::holdProfile(const QString &profile, const QString &reason, const QString &application_id)
{
    // handle method call org.kde.Solid.PowerManagement.Actions.PowerProfile.holdProfile
    return parent()->holdProfile(profile, reason, application_id);
}

QString PowerProfileAdaptor::performanceDegradedReason()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.PowerProfile.performanceDegradedReason
    return parent()->performanceDegradedReason();
}

QString PowerProfileAdaptor::performanceInhibitedReason()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.PowerProfile.performanceInhibitedReason
    return parent()->performanceInhibitedReason();
}

QStringList PowerProfileAdaptor::profileChoices()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.PowerProfile.profileChoices
    return parent()->profileChoices();
}

QList<QVariantMap> PowerProfileAdaptor::profileHolds()
{
    // handle method call org.kde.Solid.PowerManagement.Actions.PowerProfile.profileHolds
    return parent()->profileHolds();
}

void PowerProfileAdaptor::releaseProfile(uint cookie)
{
    // handle method call org.kde.Solid.PowerManagement.Actions.PowerProfile.releaseProfile
    parent()->releaseProfile(cookie);
}

void PowerProfileAdaptor::setProfile(const QString &in0)
{
    // handle method call org.kde.Solid.PowerManagement.Actions.PowerProfile.setProfile
    parent()->setProfile(in0);
}


#include "moc_powerprofileadaptor.cpp"
