/****************************************************************************
** Meta object code from reading C++ file 'screenbrightnessadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "screenbrightnessadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'screenbrightnessadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23ScreenBrightnessAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenBrightnessAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN23ScreenBrightnessAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenBrightnessAdaptor",
        "D-Bus Interface",
        "org.kde.ScreenBrightness",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.ScreenBrightness\">\n    <property acc"
        "ess=\"read\" type=\"as\" name=\"DisplaysDBusNames\">\n    </proper"
        "ty>\n    <signal name=\"DisplayAdded\">\n      <arg type=\"s\" nam"
        "e=\"display_dbus_name\"/>\n    </signal>\n    <signal name=\"Displ"
        "ayRemoved\">\n      <arg type=\"s\" name=\"display_dbus_name\"/>\n"
        "    </signal>\n    <method name=\"AdjustBrightnessRatio\">\n      "
        "<arg direction=\"in\" type=\"d\" name=\"delta\"/>\n      <arg dire"
        "ction=\"in\" type=\"u\" name=\"flags\"/>\n    </method>\n    <meth"
        "od name=\"AdjustBrightnessRatioWithContext\">\n      <arg directio"
        "n=\"in\" type=\"d\" name=\"delta\"/>\n      <arg direction=\"in\" "
        "type=\"u\" name=\"flags\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"source_client_context\"/>\n    </method>\n    <method name"
        "=\"AdjustBrightnessStep\">\n      <arg direction=\"in\" type=\"u\""
        " name=\"step_action\"/>\n      <arg direction=\"in\" type=\"u\" na"
        "me=\"flags\"/>\n    </method>\n    <method name=\"AdjustBrightness"
        "StepWithContext\">\n      <arg direction=\"in\" type=\"u\" name=\""
        "step_action\"/>\n      <arg direction=\"in\" type=\"u\" name=\"fla"
        "gs\"/>\n      <arg direction=\"in\" type=\"s\" name=\"source_clien"
        "t_context\"/>\n    </method>\n    <signal name=\"BrightnessChanged"
        "\">\n      <arg type=\"s\" name=\"display_dbus_name\"/>\n      <ar"
        "g type=\"i\" name=\"brightness\"/>\n      <arg type=\"s\" name=\"s"
        "ource_client_name\"/>\n      <arg type=\"s\" name=\"source_client_"
        "context\"/>\n    </signal>\n    <signal name=\"BrightnessRangeChan"
        "ged\">\n      <arg type=\"s\" name=\"display_dbus_name\"/>\n      "
        "<arg type=\"i\" name=\"max_brightness\"/>\n      <arg type=\"i\" n"
        "ame=\"brightness\"/>\n    </signal>\n  </interface>\n",
        "BrightnessChanged",
        "",
        "display_dbus_name",
        "brightness",
        "source_client_name",
        "source_client_context",
        "BrightnessRangeChanged",
        "max_brightness",
        "DisplayAdded",
        "DisplayRemoved",
        "AdjustBrightnessRatio",
        "delta",
        "flags",
        "AdjustBrightnessRatioWithContext",
        "AdjustBrightnessStep",
        "step_action",
        "AdjustBrightnessStepWithContext",
        "DisplaysDBusNames"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'BrightnessChanged'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &, const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 8 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'BrightnessRangeChanged'
        QtMocHelpers::SignalData<void(const QString &, int, int)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Int, 12 }, { QMetaType::Int, 8 },
        }}),
        // Signal 'DisplayAdded'
        QtMocHelpers::SignalData<void(const QString &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'DisplayRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'AdjustBrightnessRatio'
        QtMocHelpers::SlotData<void(double, uint)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 16 }, { QMetaType::UInt, 17 },
        }}),
        // Slot 'AdjustBrightnessRatioWithContext'
        QtMocHelpers::SlotData<void(double, uint, const QString &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 16 }, { QMetaType::UInt, 17 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'AdjustBrightnessStep'
        QtMocHelpers::SlotData<void(uint, uint)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 20 }, { QMetaType::UInt, 17 },
        }}),
        // Slot 'AdjustBrightnessStepWithContext'
        QtMocHelpers::SlotData<void(uint, uint, const QString &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 20 }, { QMetaType::UInt, 17 }, { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'DisplaysDBusNames'
        QtMocHelpers::PropertyData<QStringList>(22, QMetaType::QStringList, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ScreenBrightnessAdaptor, qt_meta_tag_ZN23ScreenBrightnessAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ScreenBrightnessAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ScreenBrightnessAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ScreenBrightnessAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23ScreenBrightnessAdaptorE_t>.metaTypes,
    nullptr
} };

void ScreenBrightnessAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenBrightnessAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->BrightnessChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 1: _t->BrightnessRangeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 2: _t->DisplayAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->DisplayRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->AdjustBrightnessRatio((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 5: _t->AdjustBrightnessRatioWithContext((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 6: _t->AdjustBrightnessStep((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 7: _t->AdjustBrightnessStepWithContext((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessAdaptor::*)(const QString & , int , const QString & , const QString & )>(_a, &ScreenBrightnessAdaptor::BrightnessChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessAdaptor::*)(const QString & , int , int )>(_a, &ScreenBrightnessAdaptor::BrightnessRangeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessAdaptor::*)(const QString & )>(_a, &ScreenBrightnessAdaptor::DisplayAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessAdaptor::*)(const QString & )>(_a, &ScreenBrightnessAdaptor::DisplayRemoved, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->displaysDBusNames(); break;
        default: break;
        }
    }
}

const QMetaObject *ScreenBrightnessAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenBrightnessAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ScreenBrightnessAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int ScreenBrightnessAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void ScreenBrightnessAdaptor::BrightnessChanged(const QString & _t1, int _t2, const QString & _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void ScreenBrightnessAdaptor::BrightnessRangeChanged(const QString & _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void ScreenBrightnessAdaptor::DisplayAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ScreenBrightnessAdaptor::DisplayRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
