// This file is generated by kconfig_compiler_kf6 from brightness_kdeglobalssettings.kcfg.
// All changes you do to this file will be lost.
#ifndef BRIGHTNESSGLOBALSSETTINGS_H
#define BRIGHTNESSGLOBALSSETTINGS_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class BrightnessGlobalsSettings : public KConfigSkeleton
{
  Q_OBJECT
  public:

    BrightnessGlobalsSettings( QObject *parent = nullptr );
    ~BrightnessGlobalsSettings() override;

    /**
      Set Global Look and Feel package
    */
    void setLookAndFeelPackage( const QString & v )
    {
      if (v != mLookAndFeelPackage && !isLookAndFeelPackageImmutable()) {
        mLookAndFeelPackage = v;
        Q_EMIT lookAndFeelPackageChanged();
      }
    }

    Q_PROPERTY(QString lookAndFeelPackage READ lookAndFeelPackage WRITE setLookAndFeelPackage NOTIFY lookAndFeelPackageChanged)
    Q_PROPERTY(bool isLookAndFeelPackageImmutable READ isLookAndFeelPackageImmutable CONSTANT)
    Q_PROPERTY(QString defaultLookAndFeelPackageValue READ defaultLookAndFeelPackageValue CONSTANT)
    /**
      Get Global Look and Feel package
    */
    QString lookAndFeelPackage() const
    {
      return mLookAndFeelPackage;
    }

    /**
      Is Global Look and Feel package Immutable
    */
    bool isLookAndFeelPackageImmutable() const
    {
      return isImmutable( QStringLiteral( "lookAndFeelPackage" ) );
    }

    /**
      Get Global Look and Feel package default value
    */
    QString defaultLookAndFeelPackageValue() const
    {
        return defaultLookAndFeelPackageValue_helper();
    }

    /**
      Set Global Look and Feel package, alternate
    */
    void setDefaultLightLookAndFeel( const QString & v )
    {
      if (v != mDefaultLightLookAndFeel && !isDefaultLightLookAndFeelImmutable()) {
        mDefaultLightLookAndFeel = v;
        Q_EMIT defaultLightLookAndFeelChanged();
      }
    }

    Q_PROPERTY(QString defaultLightLookAndFeel READ defaultLightLookAndFeel WRITE setDefaultLightLookAndFeel NOTIFY defaultLightLookAndFeelChanged)
    Q_PROPERTY(bool isDefaultLightLookAndFeelImmutable READ isDefaultLightLookAndFeelImmutable CONSTANT)
    Q_PROPERTY(QString defaultDefaultLightLookAndFeelValue READ defaultDefaultLightLookAndFeelValue CONSTANT)
    /**
      Get Global Look and Feel package, alternate
    */
    QString defaultLightLookAndFeel() const
    {
      return mDefaultLightLookAndFeel;
    }

    /**
      Is Global Look and Feel package, alternate Immutable
    */
    bool isDefaultLightLookAndFeelImmutable() const
    {
      return isImmutable( QStringLiteral( "defaultLightLookAndFeel" ) );
    }

    /**
      Get Global Look and Feel package, alternate default value
    */
    QString defaultDefaultLightLookAndFeelValue() const
    {
        return defaultDefaultLightLookAndFeelValue_helper();
    }

    /**
      Set Global Look and Feel package, alternate
    */
    void setDefaultDarkLookAndFeel( const QString & v )
    {
      if (v != mDefaultDarkLookAndFeel && !isDefaultDarkLookAndFeelImmutable()) {
        mDefaultDarkLookAndFeel = v;
        Q_EMIT defaultDarkLookAndFeelChanged();
      }
    }

    Q_PROPERTY(QString defaultDarkLookAndFeel READ defaultDarkLookAndFeel WRITE setDefaultDarkLookAndFeel NOTIFY defaultDarkLookAndFeelChanged)
    Q_PROPERTY(bool isDefaultDarkLookAndFeelImmutable READ isDefaultDarkLookAndFeelImmutable CONSTANT)
    Q_PROPERTY(QString defaultDefaultDarkLookAndFeelValue READ defaultDefaultDarkLookAndFeelValue CONSTANT)
    /**
      Get Global Look and Feel package, alternate
    */
    QString defaultDarkLookAndFeel() const
    {
      return mDefaultDarkLookAndFeel;
    }

    /**
      Is Global Look and Feel package, alternate Immutable
    */
    bool isDefaultDarkLookAndFeelImmutable() const
    {
      return isImmutable( QStringLiteral( "defaultDarkLookAndFeel" ) );
    }

    /**
      Get Global Look and Feel package, alternate default value
    */
    QString defaultDefaultDarkLookAndFeelValue() const
    {
        return defaultDefaultDarkLookAndFeelValue_helper();
    }


    enum {
      signalLookAndFeelPackageChanged = 1,
      signalDefaultLightLookAndFeelChanged = 2,
      signalDefaultDarkLookAndFeelChanged = 3
    };

  Q_SIGNALS:
    void lookAndFeelPackageChanged();

    void defaultLightLookAndFeelChanged();

    void defaultDarkLookAndFeelChanged();

  private:
    void itemChanged(quint64 signalFlag);

  protected:

    // KDE
    QString mLookAndFeelPackage;
    QString defaultLookAndFeelPackageValue_helper() const;
    QString mDefaultLightLookAndFeel;
    QString defaultDefaultLightLookAndFeelValue_helper() const;
    QString mDefaultDarkLookAndFeel;
    QString defaultDefaultDarkLookAndFeelValue_helper() const;
};

#endif

