/****************************************************************************
** Meta object code from reading C++ file 'keyboardbrightnesscontrol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../powerdevil-6.6.91/applets/brightness/plugin/keyboardbrightnesscontrol.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyboardbrightnesscontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25KeyboardBrightnessControlE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyboardBrightnessControl::qt_create_metaobjectdata<qt_meta_tag_ZN25KeyboardBrightnessControlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyboardBrightnessControl",
        "QML.Element",
        "auto",
        "brightnessChanged",
        "",
        "value",
        "brightnessMaxChanged",
        "isBrightnessAvailableChanged",
        "status",
        "onBrightnessChanged",
        "onBrightnessMaxChanged",
        "onSupportedActionsChanged",
        "QCoro::Task<void>",
        "brightness",
        "brightnessMax",
        "isBrightnessAvailable",
        "isSilent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'brightnessChanged'
        QtMocHelpers::SignalData<void(int)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'brightnessMaxChanged'
        QtMocHelpers::SignalData<void(int)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'isBrightnessAvailableChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'onBrightnessChanged'
        QtMocHelpers::SlotData<void(int)>(9, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'onBrightnessMaxChanged'
        QtMocHelpers::SlotData<void(int)>(10, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'onSupportedActionsChanged'
        QtMocHelpers::SlotData<QCoro::Task<void>()>(11, 4, QMC::AccessPrivate, 0x80000000 | 12),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'brightness'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Bindable, 0),
        // property 'brightnessMax'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'isBrightnessAvailable'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 2),
        // property 'isSilent'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::Stored | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KeyboardBrightnessControl, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KeyboardBrightnessControl::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KeyboardBrightnessControlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KeyboardBrightnessControlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25KeyboardBrightnessControlE_t>.metaTypes,
    nullptr
} };

void KeyboardBrightnessControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyboardBrightnessControl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->brightnessChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->brightnessMaxChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->isBrightnessAvailableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->onBrightnessChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->onBrightnessMaxChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: { QCoro::Task<void> _r = _t->onSupportedActionsChanged();
            if (_a[0]) *reinterpret_cast<QCoro::Task<void>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyboardBrightnessControl::*)(int )>(_a, &KeyboardBrightnessControl::brightnessChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardBrightnessControl::*)(int )>(_a, &KeyboardBrightnessControl::brightnessMaxChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyboardBrightnessControl::*)(bool )>(_a, &KeyboardBrightnessControl::isBrightnessAvailableChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->bindableBrightness().value(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->bindableBrightnessMax().value(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->bindableIsBrightnessAvailable().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBrightness(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setIsSilent(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableBrightness(); break;
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableBrightnessMax(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableIsBrightnessAvailable(); break;
        default: break;
        }
    }
}

const QMetaObject *KeyboardBrightnessControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyboardBrightnessControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KeyboardBrightnessControlE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KeyboardBrightnessControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KeyboardBrightnessControl::brightnessChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KeyboardBrightnessControl::brightnessMaxChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KeyboardBrightnessControl::isBrightnessAvailableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
