/****************************************************************************
** Meta object code from reading C++ file 'powermanagementfdoadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "powermanagementfdoadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powermanagementfdoadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25PowerManagementFdoAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerManagementFdoAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN25PowerManagementFdoAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerManagementFdoAdaptor",
        "D-Bus Interface",
        "org.freedesktop.PowerManagement",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.PowerManagement\">\n    <signa"
        "l name=\"CanSuspendChanged\">\n      <arg direction=\"out\" type=\""
        "b\" name=\"can_suspend\"/>\n    </signal>\n    <signal name=\"CanH"
        "ibernateChanged\">\n      <arg direction=\"out\" type=\"b\" name=\""
        "can_hibernate\"/>\n    </signal>\n    <signal name=\"CanHybridSusp"
        "endChanged\">\n      <arg direction=\"out\" type=\"b\" name=\"can_"
        "hybrid_suspend\"/>\n    </signal>\n    <signal name=\"CanSuspendTh"
        "enHibernateChanged\">\n      <arg direction=\"out\" type=\"b\" nam"
        "e=\"can_suspend_then_hibernate\"/>\n    </signal>\n    <signal nam"
        "e=\"PowerSaveStatusChanged\">\n      <arg direction=\"out\" type=\""
        "b\" name=\"save_power\"/>\n    </signal>\n    <method name=\"Suspe"
        "nd\"/>\n    <method name=\"Hibernate\"/>\n    <method name=\"CanSu"
        "spend\">\n      <arg direction=\"out\" type=\"b\" name=\"can_suspe"
        "nd\"/>\n    </method>\n    <method name=\"CanHibernate\">\n      <"
        "arg direction=\"out\" type=\"b\" name=\"can_hibernate\"/>\n    </m"
        "ethod>\n    <method name=\"CanHybridSuspend\">\n      <arg directi"
        "on=\"out\" type=\"b\" name=\"can_hybrid_suspend\"/>\n    </method>"
        "\n    <method name=\"CanSuspendThenHibernate\">\n      <arg direct"
        "ion=\"out\" type=\"b\" name=\"can_suspend_then_hibernate\"/>\n    "
        "</method>\n    <method name=\"GetPowerSaveStatus\">\n      <arg di"
        "rection=\"out\" type=\"b\" name=\"save_power\"/>\n    </method>\n "
        " </interface>\n",
        "CanHibernateChanged",
        "",
        "can_hibernate",
        "CanHybridSuspendChanged",
        "can_hybrid_suspend",
        "CanSuspendChanged",
        "can_suspend",
        "CanSuspendThenHibernateChanged",
        "can_suspend_then_hibernate",
        "PowerSaveStatusChanged",
        "save_power",
        "CanHibernate",
        "CanHybridSuspend",
        "CanSuspend",
        "CanSuspendThenHibernate",
        "GetPowerSaveStatus",
        "Hibernate",
        "Suspend"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'CanHibernateChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'CanHybridSuspendChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'CanSuspendChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'CanSuspendThenHibernateChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'PowerSaveStatusChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'CanHibernate'
        QtMocHelpers::SlotData<bool()>(16, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'CanHybridSuspend'
        QtMocHelpers::SlotData<bool()>(17, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'CanSuspend'
        QtMocHelpers::SlotData<bool()>(18, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'CanSuspendThenHibernate'
        QtMocHelpers::SlotData<bool()>(19, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'GetPowerSaveStatus'
        QtMocHelpers::SlotData<bool()>(20, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'Hibernate'
        QtMocHelpers::SlotData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'Suspend'
        QtMocHelpers::SlotData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PowerManagementFdoAdaptor, qt_meta_tag_ZN25PowerManagementFdoAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PowerManagementFdoAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25PowerManagementFdoAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25PowerManagementFdoAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25PowerManagementFdoAdaptorE_t>.metaTypes,
    nullptr
} };

void PowerManagementFdoAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerManagementFdoAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CanHibernateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->CanHybridSuspendChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->CanSuspendChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->CanSuspendThenHibernateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->PowerSaveStatusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: { bool _r = _t->CanHibernate();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->CanHybridSuspend();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->CanSuspend();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->CanSuspendThenHibernate();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->GetPowerSaveStatus();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->Hibernate(); break;
        case 11: _t->Suspend(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PowerManagementFdoAdaptor::*)(bool )>(_a, &PowerManagementFdoAdaptor::CanHibernateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagementFdoAdaptor::*)(bool )>(_a, &PowerManagementFdoAdaptor::CanHybridSuspendChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagementFdoAdaptor::*)(bool )>(_a, &PowerManagementFdoAdaptor::CanSuspendChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagementFdoAdaptor::*)(bool )>(_a, &PowerManagementFdoAdaptor::CanSuspendThenHibernateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerManagementFdoAdaptor::*)(bool )>(_a, &PowerManagementFdoAdaptor::PowerSaveStatusChanged, 4))
            return;
    }
}

const QMetaObject *PowerManagementFdoAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerManagementFdoAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25PowerManagementFdoAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int PowerManagementFdoAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void PowerManagementFdoAdaptor::CanHibernateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PowerManagementFdoAdaptor::CanHybridSuspendChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PowerManagementFdoAdaptor::CanSuspendChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PowerManagementFdoAdaptor::CanSuspendThenHibernateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PowerManagementFdoAdaptor::PowerSaveStatusChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
