/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ScreenBrightness.Display.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef SCREENBRIGHTNESSDISPLAYADAPTOR_H
#define SCREENBRIGHTNESSDISPLAYADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "powerdevilscreenbrightnessagent.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.ScreenBrightness.Display
 */
class ScreenBrightnessDisplayAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.ScreenBrightness.Display")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.ScreenBrightness.Display\">\n"
"    <property access=\"read\" type=\"s\" name=\"Label\">\n"
"    </property>\n"
"    <property access=\"read\" type=\"b\" name=\"IsInternal\">\n"
"    </property>\n"
"    <property access=\"read\" type=\"i\" name=\"MaxBrightness\">\n"
"    </property>\n"
"    <property access=\"read\" type=\"i\" name=\"Brightness\">\n"
"    </property>\n"
"    <method name=\"SetBrightness\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"brightness\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"    </method>\n"
"    <method name=\"SetBrightnessWithContext\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"brightness\"/>\n"
"      <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"source_client_context\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    ScreenBrightnessDisplayAdaptor(PowerDevil::ScreenBrightnessDisplay *parent);
    ~ScreenBrightnessDisplayAdaptor() override;

    inline PowerDevil::ScreenBrightnessDisplay *parent() const
    { return static_cast<PowerDevil::ScreenBrightnessDisplay *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(int Brightness READ brightness)
    int brightness() const;

    Q_PROPERTY(bool IsInternal READ isInternal)
    bool isInternal() const;

    Q_PROPERTY(QString Label READ label)
    QString label() const;

    Q_PROPERTY(int MaxBrightness READ maxBrightness)
    int maxBrightness() const;

public Q_SLOTS: // METHODS
    void SetBrightness(int brightness, uint flags);
    void SetBrightnessWithContext(int brightness, uint flags, const QString &source_client_context);
Q_SIGNALS: // SIGNALS
};

#endif
