/****************************************************************************
** Meta object code from reading C++ file 'PowerDevilProfileSettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../PowerDevilProfileSettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PowerDevilProfileSettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PowerDevil15ProfileSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::ProfileSettings::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevil15ProfileSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil::ProfileSettings",
        "UseProfileSpecificKeyboardBrightnessChanged",
        "",
        "KeyboardBrightnessChanged",
        "UseProfileSpecificDisplayBrightnessChanged",
        "DisplayBrightnessChanged",
        "DimDisplayWhenIdleChanged",
        "DimDisplayIdleTimeoutSecChanged",
        "TurnOffDisplayWhenIdleChanged",
        "TurnOffDisplayIdleTimeoutSecChanged",
        "TurnOffDisplayIdleTimeoutWhenLockedSecChanged",
        "LockBeforeTurnOffDisplayChanged",
        "AutoSuspendActionChanged",
        "AutoSuspendIdleTimeoutSecChanged",
        "PowerButtonActionChanged",
        "PowerDownActionChanged",
        "LidActionChanged",
        "InhibitLidActionWhenExternalMonitorPresentChanged",
        "SleepModeChanged",
        "PowerProfileChanged",
        "ProfileLoadCommandChanged",
        "ProfileUnloadCommandChanged",
        "IdleTimeoutCommandChanged",
        "RunScriptIdleTimeoutSecChanged",
        "useProfileSpecificKeyboardBrightness",
        "isUseProfileSpecificKeyboardBrightnessImmutable",
        "defaultUseProfileSpecificKeyboardBrightnessValue",
        "keyboardBrightness",
        "isKeyboardBrightnessImmutable",
        "defaultKeyboardBrightnessValue",
        "useProfileSpecificDisplayBrightness",
        "isUseProfileSpecificDisplayBrightnessImmutable",
        "defaultUseProfileSpecificDisplayBrightnessValue",
        "displayBrightness",
        "isDisplayBrightnessImmutable",
        "defaultDisplayBrightnessValue",
        "dimDisplayWhenIdle",
        "isDimDisplayWhenIdleImmutable",
        "defaultDimDisplayWhenIdleValue",
        "dimDisplayIdleTimeoutSec",
        "isDimDisplayIdleTimeoutSecImmutable",
        "defaultDimDisplayIdleTimeoutSecValue",
        "turnOffDisplayWhenIdle",
        "isTurnOffDisplayWhenIdleImmutable",
        "defaultTurnOffDisplayWhenIdleValue",
        "turnOffDisplayIdleTimeoutSec",
        "isTurnOffDisplayIdleTimeoutSecImmutable",
        "defaultTurnOffDisplayIdleTimeoutSecValue",
        "turnOffDisplayIdleTimeoutWhenLockedSec",
        "isTurnOffDisplayIdleTimeoutWhenLockedSecImmutable",
        "defaultTurnOffDisplayIdleTimeoutWhenLockedSecValue",
        "lockBeforeTurnOffDisplay",
        "isLockBeforeTurnOffDisplayImmutable",
        "defaultLockBeforeTurnOffDisplayValue",
        "autoSuspendAction",
        "isAutoSuspendActionImmutable",
        "defaultAutoSuspendActionValue",
        "autoSuspendIdleTimeoutSec",
        "isAutoSuspendIdleTimeoutSecImmutable",
        "defaultAutoSuspendIdleTimeoutSecValue",
        "powerButtonAction",
        "isPowerButtonActionImmutable",
        "defaultPowerButtonActionValue",
        "powerDownAction",
        "isPowerDownActionImmutable",
        "defaultPowerDownActionValue",
        "lidAction",
        "isLidActionImmutable",
        "defaultLidActionValue",
        "inhibitLidActionWhenExternalMonitorPresent",
        "isInhibitLidActionWhenExternalMonitorPresentImmutable",
        "defaultInhibitLidActionWhenExternalMonitorPresentValue",
        "sleepMode",
        "isSleepModeImmutable",
        "defaultSleepModeValue",
        "powerProfile",
        "isPowerProfileImmutable",
        "profileLoadCommand",
        "isProfileLoadCommandImmutable",
        "profileUnloadCommand",
        "isProfileUnloadCommandImmutable",
        "idleTimeoutCommand",
        "isIdleTimeoutCommandImmutable",
        "runScriptIdleTimeoutSec",
        "isRunScriptIdleTimeoutSecImmutable",
        "defaultRunScriptIdleTimeoutSecValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'UseProfileSpecificKeyboardBrightnessChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'KeyboardBrightnessChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseProfileSpecificDisplayBrightnessChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DisplayBrightnessChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DimDisplayWhenIdleChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DimDisplayIdleTimeoutSecChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TurnOffDisplayWhenIdleChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TurnOffDisplayIdleTimeoutSecChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'TurnOffDisplayIdleTimeoutWhenLockedSecChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LockBeforeTurnOffDisplayChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoSuspendActionChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AutoSuspendIdleTimeoutSecChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PowerButtonActionChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PowerDownActionChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'LidActionChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'InhibitLidActionWhenExternalMonitorPresentChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SleepModeChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PowerProfileChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProfileLoadCommandChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ProfileUnloadCommandChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'IdleTimeoutCommandChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'RunScriptIdleTimeoutSecChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'useProfileSpecificKeyboardBrightness'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isUseProfileSpecificKeyboardBrightnessImmutable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUseProfileSpecificKeyboardBrightnessValue'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'keyboardBrightness'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isKeyboardBrightnessImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultKeyboardBrightnessValue'
        QtMocHelpers::PropertyData<int>(29, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useProfileSpecificDisplayBrightness'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isUseProfileSpecificDisplayBrightnessImmutable'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUseProfileSpecificDisplayBrightnessValue'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayBrightness'
        QtMocHelpers::PropertyData<int>(33, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isDisplayBrightnessImmutable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayBrightnessValue'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dimDisplayWhenIdle'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isDimDisplayWhenIdleImmutable'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDimDisplayWhenIdleValue'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dimDisplayIdleTimeoutSec'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isDimDisplayIdleTimeoutSecImmutable'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDimDisplayIdleTimeoutSecValue'
        QtMocHelpers::PropertyData<int>(41, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'turnOffDisplayWhenIdle'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isTurnOffDisplayWhenIdleImmutable'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTurnOffDisplayWhenIdleValue'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'turnOffDisplayIdleTimeoutSec'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isTurnOffDisplayIdleTimeoutSecImmutable'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTurnOffDisplayIdleTimeoutSecValue'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'turnOffDisplayIdleTimeoutWhenLockedSec'
        QtMocHelpers::PropertyData<int>(48, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isTurnOffDisplayIdleTimeoutWhenLockedSecImmutable'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTurnOffDisplayIdleTimeoutWhenLockedSecValue'
        QtMocHelpers::PropertyData<int>(50, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lockBeforeTurnOffDisplay'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isLockBeforeTurnOffDisplayImmutable'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLockBeforeTurnOffDisplayValue'
        QtMocHelpers::PropertyData<bool>(53, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoSuspendAction'
        QtMocHelpers::PropertyData<uint>(54, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isAutoSuspendActionImmutable'
        QtMocHelpers::PropertyData<bool>(55, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoSuspendActionValue'
        QtMocHelpers::PropertyData<uint>(56, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoSuspendIdleTimeoutSec'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isAutoSuspendIdleTimeoutSecImmutable'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoSuspendIdleTimeoutSecValue'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'powerButtonAction'
        QtMocHelpers::PropertyData<uint>(60, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isPowerButtonActionImmutable'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPowerButtonActionValue'
        QtMocHelpers::PropertyData<uint>(62, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'powerDownAction'
        QtMocHelpers::PropertyData<uint>(63, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isPowerDownActionImmutable'
        QtMocHelpers::PropertyData<bool>(64, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPowerDownActionValue'
        QtMocHelpers::PropertyData<uint>(65, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lidAction'
        QtMocHelpers::PropertyData<uint>(66, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isLidActionImmutable'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLidActionValue'
        QtMocHelpers::PropertyData<uint>(68, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'inhibitLidActionWhenExternalMonitorPresent'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isInhibitLidActionWhenExternalMonitorPresentImmutable'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInhibitLidActionWhenExternalMonitorPresentValue'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sleepMode'
        QtMocHelpers::PropertyData<uint>(72, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isSleepModeImmutable'
        QtMocHelpers::PropertyData<bool>(73, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSleepModeValue'
        QtMocHelpers::PropertyData<uint>(74, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'powerProfile'
        QtMocHelpers::PropertyData<QString>(75, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isPowerProfileImmutable'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'profileLoadCommand'
        QtMocHelpers::PropertyData<QString>(77, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isProfileLoadCommandImmutable'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'profileUnloadCommand'
        QtMocHelpers::PropertyData<QString>(79, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isProfileUnloadCommandImmutable'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'idleTimeoutCommand'
        QtMocHelpers::PropertyData<QString>(81, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isIdleTimeoutCommandImmutable'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'runScriptIdleTimeoutSec'
        QtMocHelpers::PropertyData<int>(83, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isRunScriptIdleTimeoutSecImmutable'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRunScriptIdleTimeoutSecValue'
        QtMocHelpers::PropertyData<int>(85, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProfileSettings, qt_meta_tag_ZN10PowerDevil15ProfileSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PowerDevil::ProfileSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil15ProfileSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil15ProfileSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerDevil15ProfileSettingsE_t>.metaTypes,
    nullptr
} };

void PowerDevil::ProfileSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProfileSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->UseProfileSpecificKeyboardBrightnessChanged(); break;
        case 1: _t->KeyboardBrightnessChanged(); break;
        case 2: _t->UseProfileSpecificDisplayBrightnessChanged(); break;
        case 3: _t->DisplayBrightnessChanged(); break;
        case 4: _t->DimDisplayWhenIdleChanged(); break;
        case 5: _t->DimDisplayIdleTimeoutSecChanged(); break;
        case 6: _t->TurnOffDisplayWhenIdleChanged(); break;
        case 7: _t->TurnOffDisplayIdleTimeoutSecChanged(); break;
        case 8: _t->TurnOffDisplayIdleTimeoutWhenLockedSecChanged(); break;
        case 9: _t->LockBeforeTurnOffDisplayChanged(); break;
        case 10: _t->AutoSuspendActionChanged(); break;
        case 11: _t->AutoSuspendIdleTimeoutSecChanged(); break;
        case 12: _t->PowerButtonActionChanged(); break;
        case 13: _t->PowerDownActionChanged(); break;
        case 14: _t->LidActionChanged(); break;
        case 15: _t->InhibitLidActionWhenExternalMonitorPresentChanged(); break;
        case 16: _t->SleepModeChanged(); break;
        case 17: _t->PowerProfileChanged(); break;
        case 18: _t->ProfileLoadCommandChanged(); break;
        case 19: _t->ProfileUnloadCommandChanged(); break;
        case 20: _t->IdleTimeoutCommandChanged(); break;
        case 21: _t->RunScriptIdleTimeoutSecChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::UseProfileSpecificKeyboardBrightnessChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::KeyboardBrightnessChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::UseProfileSpecificDisplayBrightnessChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::DisplayBrightnessChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::DimDisplayWhenIdleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::DimDisplayIdleTimeoutSecChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::TurnOffDisplayWhenIdleChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::TurnOffDisplayIdleTimeoutSecChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::TurnOffDisplayIdleTimeoutWhenLockedSecChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::LockBeforeTurnOffDisplayChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::AutoSuspendActionChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::AutoSuspendIdleTimeoutSecChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::PowerButtonActionChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::PowerDownActionChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::LidActionChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::InhibitLidActionWhenExternalMonitorPresentChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::SleepModeChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::PowerProfileChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::ProfileLoadCommandChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::ProfileUnloadCommandChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::IdleTimeoutCommandChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProfileSettings::*)()>(_a, &ProfileSettings::RunScriptIdleTimeoutSecChanged, 21))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->useProfileSpecificKeyboardBrightness(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isUseProfileSpecificKeyboardBrightnessImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->defaultUseProfileSpecificKeyboardBrightnessValue(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->keyboardBrightness(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isKeyboardBrightnessImmutable(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->defaultKeyboardBrightnessValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->useProfileSpecificDisplayBrightness(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isUseProfileSpecificDisplayBrightnessImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultUseProfileSpecificDisplayBrightnessValue(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->displayBrightness(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isDisplayBrightnessImmutable(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->defaultDisplayBrightnessValue(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->dimDisplayWhenIdle(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isDimDisplayWhenIdleImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->defaultDimDisplayWhenIdleValue(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->dimDisplayIdleTimeoutSec(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isDimDisplayIdleTimeoutSecImmutable(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->defaultDimDisplayIdleTimeoutSecValue(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->turnOffDisplayWhenIdle(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isTurnOffDisplayWhenIdleImmutable(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->defaultTurnOffDisplayWhenIdleValue(); break;
        case 21: *reinterpret_cast<int*>(_v) = _t->turnOffDisplayIdleTimeoutSec(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isTurnOffDisplayIdleTimeoutSecImmutable(); break;
        case 23: *reinterpret_cast<int*>(_v) = _t->defaultTurnOffDisplayIdleTimeoutSecValue(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->turnOffDisplayIdleTimeoutWhenLockedSec(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isTurnOffDisplayIdleTimeoutWhenLockedSecImmutable(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->defaultTurnOffDisplayIdleTimeoutWhenLockedSecValue(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->lockBeforeTurnOffDisplay(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isLockBeforeTurnOffDisplayImmutable(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->defaultLockBeforeTurnOffDisplayValue(); break;
        case 30: *reinterpret_cast<uint*>(_v) = _t->autoSuspendAction(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isAutoSuspendActionImmutable(); break;
        case 32: *reinterpret_cast<uint*>(_v) = _t->defaultAutoSuspendActionValue(); break;
        case 33: *reinterpret_cast<int*>(_v) = _t->autoSuspendIdleTimeoutSec(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->isAutoSuspendIdleTimeoutSecImmutable(); break;
        case 35: *reinterpret_cast<int*>(_v) = _t->defaultAutoSuspendIdleTimeoutSecValue(); break;
        case 36: *reinterpret_cast<uint*>(_v) = _t->powerButtonAction(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->isPowerButtonActionImmutable(); break;
        case 38: *reinterpret_cast<uint*>(_v) = _t->defaultPowerButtonActionValue(); break;
        case 39: *reinterpret_cast<uint*>(_v) = _t->powerDownAction(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isPowerDownActionImmutable(); break;
        case 41: *reinterpret_cast<uint*>(_v) = _t->defaultPowerDownActionValue(); break;
        case 42: *reinterpret_cast<uint*>(_v) = _t->lidAction(); break;
        case 43: *reinterpret_cast<bool*>(_v) = _t->isLidActionImmutable(); break;
        case 44: *reinterpret_cast<uint*>(_v) = _t->defaultLidActionValue(); break;
        case 45: *reinterpret_cast<bool*>(_v) = _t->inhibitLidActionWhenExternalMonitorPresent(); break;
        case 46: *reinterpret_cast<bool*>(_v) = _t->isInhibitLidActionWhenExternalMonitorPresentImmutable(); break;
        case 47: *reinterpret_cast<bool*>(_v) = _t->defaultInhibitLidActionWhenExternalMonitorPresentValue(); break;
        case 48: *reinterpret_cast<uint*>(_v) = _t->sleepMode(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->isSleepModeImmutable(); break;
        case 50: *reinterpret_cast<uint*>(_v) = _t->defaultSleepModeValue(); break;
        case 51: *reinterpret_cast<QString*>(_v) = _t->powerProfile(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->isPowerProfileImmutable(); break;
        case 53: *reinterpret_cast<QString*>(_v) = _t->profileLoadCommand(); break;
        case 54: *reinterpret_cast<bool*>(_v) = _t->isProfileLoadCommandImmutable(); break;
        case 55: *reinterpret_cast<QString*>(_v) = _t->profileUnloadCommand(); break;
        case 56: *reinterpret_cast<bool*>(_v) = _t->isProfileUnloadCommandImmutable(); break;
        case 57: *reinterpret_cast<QString*>(_v) = _t->idleTimeoutCommand(); break;
        case 58: *reinterpret_cast<bool*>(_v) = _t->isIdleTimeoutCommandImmutable(); break;
        case 59: *reinterpret_cast<int*>(_v) = _t->runScriptIdleTimeoutSec(); break;
        case 60: *reinterpret_cast<bool*>(_v) = _t->isRunScriptIdleTimeoutSecImmutable(); break;
        case 61: *reinterpret_cast<int*>(_v) = _t->defaultRunScriptIdleTimeoutSecValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUseProfileSpecificKeyboardBrightness(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setKeyboardBrightness(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setUseProfileSpecificDisplayBrightness(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setDisplayBrightness(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setDimDisplayWhenIdle(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setDimDisplayIdleTimeoutSec(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setTurnOffDisplayWhenIdle(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setTurnOffDisplayIdleTimeoutSec(*reinterpret_cast<int*>(_v)); break;
        case 24: _t->setTurnOffDisplayIdleTimeoutWhenLockedSec(*reinterpret_cast<int*>(_v)); break;
        case 27: _t->setLockBeforeTurnOffDisplay(*reinterpret_cast<bool*>(_v)); break;
        case 30: _t->setAutoSuspendAction(*reinterpret_cast<uint*>(_v)); break;
        case 33: _t->setAutoSuspendIdleTimeoutSec(*reinterpret_cast<int*>(_v)); break;
        case 36: _t->setPowerButtonAction(*reinterpret_cast<uint*>(_v)); break;
        case 39: _t->setPowerDownAction(*reinterpret_cast<uint*>(_v)); break;
        case 42: _t->setLidAction(*reinterpret_cast<uint*>(_v)); break;
        case 45: _t->setInhibitLidActionWhenExternalMonitorPresent(*reinterpret_cast<bool*>(_v)); break;
        case 48: _t->setSleepMode(*reinterpret_cast<uint*>(_v)); break;
        case 51: _t->setPowerProfile(*reinterpret_cast<QString*>(_v)); break;
        case 53: _t->setProfileLoadCommand(*reinterpret_cast<QString*>(_v)); break;
        case 55: _t->setProfileUnloadCommand(*reinterpret_cast<QString*>(_v)); break;
        case 57: _t->setIdleTimeoutCommand(*reinterpret_cast<QString*>(_v)); break;
        case 59: _t->setRunScriptIdleTimeoutSec(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PowerDevil::ProfileSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDevil::ProfileSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil15ProfileSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int PowerDevil::ProfileSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 62;
    }
    return _id;
}

// SIGNAL 0
void PowerDevil::ProfileSettings::UseProfileSpecificKeyboardBrightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PowerDevil::ProfileSettings::KeyboardBrightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PowerDevil::ProfileSettings::UseProfileSpecificDisplayBrightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PowerDevil::ProfileSettings::DisplayBrightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PowerDevil::ProfileSettings::DimDisplayWhenIdleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PowerDevil::ProfileSettings::DimDisplayIdleTimeoutSecChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PowerDevil::ProfileSettings::TurnOffDisplayWhenIdleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PowerDevil::ProfileSettings::TurnOffDisplayIdleTimeoutSecChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PowerDevil::ProfileSettings::TurnOffDisplayIdleTimeoutWhenLockedSecChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PowerDevil::ProfileSettings::LockBeforeTurnOffDisplayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void PowerDevil::ProfileSettings::AutoSuspendActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void PowerDevil::ProfileSettings::AutoSuspendIdleTimeoutSecChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void PowerDevil::ProfileSettings::PowerButtonActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void PowerDevil::ProfileSettings::PowerDownActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void PowerDevil::ProfileSettings::LidActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void PowerDevil::ProfileSettings::InhibitLidActionWhenExternalMonitorPresentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void PowerDevil::ProfileSettings::SleepModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void PowerDevil::ProfileSettings::PowerProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void PowerDevil::ProfileSettings::ProfileLoadCommandChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void PowerDevil::ProfileSettings::ProfileUnloadCommandChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void PowerDevil::ProfileSettings::IdleTimeoutCommandChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void PowerDevil::ProfileSettings::RunScriptIdleTimeoutSecChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}
QT_WARNING_POP
