/****************************************************************************
** Meta object code from reading C++ file 'powerprofilescontrol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../powerdevil-6.6.91/applets/batterymonitor/plugin/powerprofilescontrol.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#include <QtCore/QProperty>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powerprofilescontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20PowerProfilesControlE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerProfilesControl::qt_create_metaobjectdata<qt_meta_tag_ZN20PowerProfilesControlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerProfilesControl",
        "QML.Element",
        "auto",
        "isPowerProfileDaemonInstalledChanged",
        "",
        "status",
        "profilesChanged",
        "profiles",
        "configuredProfileChanged",
        "profile",
        "activeProfileChanged",
        "profileErrorChanged",
        "inhibitionReasonChanged",
        "reason",
        "degradationReasonChanged",
        "profileHoldsChanged",
        "QList<QVariantMap>",
        "profileHolds",
        "isTlpInstallChanged",
        "installed",
        "onServiceRegistered",
        "onServiceUnregistered",
        "serviceName",
        "updatePowerProfileChoices",
        "choices",
        "updatePowerProfileConfiguredProfile",
        "updatePowerProfileCurrentProfile",
        "updatePowerProfilePerformanceInhibitedReason",
        "updatePowerProfilePerformanceDegradedReason",
        "updatePowerProfileHolds",
        "holds",
        "setProfile",
        "isPowerProfileDaemonInstalled",
        "configuredProfile",
        "activeProfile",
        "profileError",
        "inhibitionReason",
        "degradationReason",
        "isSilent",
        "isTlpInstalled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'isPowerProfileDaemonInstalledChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'profilesChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Signal 'configuredProfileChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'activeProfileChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'profileErrorChanged'
        QtMocHelpers::SignalData<void(const QString &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'inhibitionReasonChanged'
        QtMocHelpers::SignalData<void(const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'degradationReasonChanged'
        QtMocHelpers::SignalData<void(const QString &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'profileHoldsChanged'
        QtMocHelpers::SignalData<void(const QList<QVariantMap> &)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Signal 'isTlpInstallChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'onServiceRegistered'
        QtMocHelpers::SlotData<void()>(20, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onServiceUnregistered'
        QtMocHelpers::SlotData<void(const QString &)>(21, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'updatePowerProfileChoices'
        QtMocHelpers::SlotData<void(const QStringList &)>(23, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 24 },
        }}),
        // Slot 'updatePowerProfileConfiguredProfile'
        QtMocHelpers::SlotData<void(const QString &)>(25, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'updatePowerProfileCurrentProfile'
        QtMocHelpers::SlotData<void(const QString &)>(26, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'updatePowerProfilePerformanceInhibitedReason'
        QtMocHelpers::SlotData<void(const QString &)>(27, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'updatePowerProfilePerformanceDegradedReason'
        QtMocHelpers::SlotData<void(const QString &)>(28, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'updatePowerProfileHolds'
        QtMocHelpers::SlotData<void(QList<QVariantMap>)>(29, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 30 },
        }}),
        // Method 'setProfile'
        QtMocHelpers::MethodData<void(const QString &)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isPowerProfileDaemonInstalled'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 0),
        // property 'profiles'
        QtMocHelpers::PropertyData<QStringList>(7, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Bindable, 1),
        // property 'configuredProfile'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 2),
        // property 'activeProfile'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 3),
        // property 'profileError'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Bindable, 4),
        // property 'inhibitionReason'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 5),
        // property 'degradationReason'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Bindable, 6),
        // property 'profileHolds'
        QtMocHelpers::PropertyData<QList<QVariantMap>>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Bindable, 7),
        // property 'isSilent'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'isTlpInstalled'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Bindable, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PowerProfilesControl, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PowerProfilesControl::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20PowerProfilesControlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20PowerProfilesControlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20PowerProfilesControlE_t>.metaTypes,
    nullptr
} };

void PowerProfilesControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerProfilesControl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->isPowerProfileDaemonInstalledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->profilesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->configuredProfileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->activeProfileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->profileErrorChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->inhibitionReasonChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->degradationReasonChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->profileHoldsChanged((*reinterpret_cast<std::add_pointer_t<QList<QVariantMap>>>(_a[1]))); break;
        case 8: _t->isTlpInstallChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->onServiceRegistered(); break;
        case 10: _t->onServiceUnregistered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->updatePowerProfileChoices((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 12: _t->updatePowerProfileConfiguredProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->updatePowerProfileCurrentProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->updatePowerProfilePerformanceInhibitedReason((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->updatePowerProfilePerformanceDegradedReason((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->updatePowerProfileHolds((*reinterpret_cast<std::add_pointer_t<QList<QVariantMap>>>(_a[1]))); break;
        case 17: _t->setProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PowerProfilesControl::*)(bool )>(_a, &PowerProfilesControl::isPowerProfileDaemonInstalledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfilesControl::*)(const QStringList & )>(_a, &PowerProfilesControl::profilesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfilesControl::*)(const QString & )>(_a, &PowerProfilesControl::configuredProfileChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfilesControl::*)(const QString & )>(_a, &PowerProfilesControl::activeProfileChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfilesControl::*)(const QString & )>(_a, &PowerProfilesControl::profileErrorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfilesControl::*)(const QString & )>(_a, &PowerProfilesControl::inhibitionReasonChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfilesControl::*)(const QString & )>(_a, &PowerProfilesControl::degradationReasonChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfilesControl::*)(const QList<QVariantMap> & )>(_a, &PowerProfilesControl::profileHoldsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfilesControl::*)(bool )>(_a, &PowerProfilesControl::isTlpInstallChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->bindableIsPowerProfileDaemonInstalled().value(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->bindableProfiles().value(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->bindableConfiguredProfile().value(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->bindableActiveProfile().value(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->bindableProfileError().value(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->bindableInhibitionReason().value(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->bindableDegradationReason().value(); break;
        case 7: *reinterpret_cast<QList<QVariantMap>*>(_v) = _t->bindableProfileHolds().value(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isSilent(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->bindableIsTlpInstalled().value(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: {
            _t->bindableProfileError().setValue(*reinterpret_cast<QString*>(_v));
            break;
        }
        case 8: _t->setIsSilent(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::BindableProperty) {
        switch (_id) {
        case 0: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableIsPowerProfileDaemonInstalled(); break;
        case 1: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableProfiles(); break;
        case 2: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableConfiguredProfile(); break;
        case 3: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableActiveProfile(); break;
        case 4: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableProfileError(); break;
        case 5: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableInhibitionReason(); break;
        case 6: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableDegradationReason(); break;
        case 7: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableProfileHolds(); break;
        case 9: *static_cast<QUntypedBindable *>(_a[0]) = _t->bindableIsTlpInstalled(); break;
        default: break;
        }
    }
}

const QMetaObject *PowerProfilesControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerProfilesControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20PowerProfilesControlE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PowerProfilesControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void PowerProfilesControl::isPowerProfileDaemonInstalledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PowerProfilesControl::profilesChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PowerProfilesControl::configuredProfileChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PowerProfilesControl::activeProfileChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PowerProfilesControl::profileErrorChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PowerProfilesControl::inhibitionReasonChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void PowerProfilesControl::degradationReasonChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void PowerProfilesControl::profileHoldsChanged(const QList<QVariantMap> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void PowerProfilesControl::isTlpInstallChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
