/****************************************************************************
** Meta object code from reading C++ file 'PowerKCM.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../powerdevil-6.6.91/kcm/PowerKCM.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PowerKCM.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PowerDevil15PowerConfigDataE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::PowerConfigData::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevil15PowerConfigDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil::PowerConfigData",
        "global",
        "profileAC",
        "profileBattery",
        "profileLowBattery"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'global'
        QtMocHelpers::PropertyData<QObject*>(1, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'profileAC'
        QtMocHelpers::PropertyData<QObject*>(2, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'profileBattery'
        QtMocHelpers::PropertyData<QObject*>(3, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'profileLowBattery'
        QtMocHelpers::PropertyData<QObject*>(4, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PowerConfigData, qt_meta_tag_ZN10PowerDevil15PowerConfigDataE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PowerDevil::PowerConfigData::staticMetaObject = { {
    QMetaObject::SuperData::link<KCModuleData::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil15PowerConfigDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil15PowerConfigDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerDevil15PowerConfigDataE_t>.metaTypes,
    nullptr
} };

void PowerDevil::PowerConfigData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerConfigData *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->global(); break;
        case 1: *reinterpret_cast<QObject**>(_v) = _t->profileAC(); break;
        case 2: *reinterpret_cast<QObject**>(_v) = _t->profileBattery(); break;
        case 3: *reinterpret_cast<QObject**>(_v) = _t->profileLowBattery(); break;
        default: break;
        }
    }
}

const QMetaObject *PowerDevil::PowerConfigData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDevil::PowerConfigData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil15PowerConfigDataE_t>.strings))
        return static_cast<void*>(this);
    return KCModuleData::qt_metacast(_clname);
}

int PowerDevil::PowerConfigData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KCModuleData::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN10PowerDevil8PowerKCME_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::PowerKCM::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevil8PowerKCME_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil::PowerKCM",
        "supportedActionsChanged",
        "",
        "currentProfileChanged",
        "supportsBatteryProfilesChanged",
        "isPowerSupplyBatteryPresentChanged",
        "isPeripheralBatteryPresentChanged",
        "isLidPresentChanged",
        "isPowerButtonPresentChanged",
        "isBatteryConservationModeSupportedChanged",
        "isChargeStartThresholdSupportedChanged",
        "isChargeStopThresholdSupportedChanged",
        "chargeStopThresholdMightNeedReconnectChanged",
        "powerManagementServiceRegisteredChanged",
        "powerManagementServiceErrorReasonChanged",
        "load",
        "save",
        "supportedActions",
        "QVariantMap",
        "settings",
        "externalServiceSettings",
        "currentProfile",
        "supportsBatteryProfiles",
        "isPowerSupplyBatteryPresent",
        "isPeripheralBatteryPresent",
        "isLidPresent",
        "isPowerButtonPresent",
        "isBatteryConservationModeSupported",
        "isChargeStartThresholdSupported",
        "isChargeStopThresholdSupported",
        "chargeStopThresholdMightNeedReconnect",
        "powerManagementServiceRegistered",
        "powerManagementServiceErrorReason",
        "autoSuspendActionModel",
        "batteryCriticalActionModel",
        "powerButtonActionModel",
        "lidActionModel",
        "sleepModeModel",
        "powerProfileModel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'supportedActionsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentProfileChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportsBatteryProfilesChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isPowerSupplyBatteryPresentChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isPeripheralBatteryPresentChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isLidPresentChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isPowerButtonPresentChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isBatteryConservationModeSupportedChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isChargeStartThresholdSupportedChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isChargeStopThresholdSupportedChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'chargeStopThresholdMightNeedReconnectChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'powerManagementServiceRegisteredChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'powerManagementServiceErrorReasonChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'supportedActions'
        QtMocHelpers::PropertyData<QVariantMap>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'settings'
        QtMocHelpers::PropertyData<QObject*>(19, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'externalServiceSettings'
        QtMocHelpers::PropertyData<QObject*>(20, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'currentProfile'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'supportsBatteryProfiles'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'isPowerSupplyBatteryPresent'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'isPeripheralBatteryPresent'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'isLidPresent'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'isPowerButtonPresent'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'isBatteryConservationModeSupported'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'isChargeStartThresholdSupported'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags, 8),
        // property 'isChargeStopThresholdSupported'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'chargeStopThresholdMightNeedReconnect'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'powerManagementServiceRegistered'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
        // property 'powerManagementServiceErrorReason'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'autoSuspendActionModel'
        QtMocHelpers::PropertyData<QObject*>(33, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'batteryCriticalActionModel'
        QtMocHelpers::PropertyData<QObject*>(34, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'powerButtonActionModel'
        QtMocHelpers::PropertyData<QObject*>(35, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lidActionModel'
        QtMocHelpers::PropertyData<QObject*>(36, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sleepModeModel'
        QtMocHelpers::PropertyData<QObject*>(37, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'powerProfileModel'
        QtMocHelpers::PropertyData<QObject*>(38, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PowerKCM, qt_meta_tag_ZN10PowerDevil8PowerKCME_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PowerDevil::PowerKCM::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil8PowerKCME_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil8PowerKCME_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerDevil8PowerKCME_t>.metaTypes,
    nullptr
} };

void PowerDevil::PowerKCM::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerKCM *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->supportedActionsChanged(); break;
        case 1: _t->currentProfileChanged(); break;
        case 2: _t->supportsBatteryProfilesChanged(); break;
        case 3: _t->isPowerSupplyBatteryPresentChanged(); break;
        case 4: _t->isPeripheralBatteryPresentChanged(); break;
        case 5: _t->isLidPresentChanged(); break;
        case 6: _t->isPowerButtonPresentChanged(); break;
        case 7: _t->isBatteryConservationModeSupportedChanged(); break;
        case 8: _t->isChargeStartThresholdSupportedChanged(); break;
        case 9: _t->isChargeStopThresholdSupportedChanged(); break;
        case 10: _t->chargeStopThresholdMightNeedReconnectChanged(); break;
        case 11: _t->powerManagementServiceRegisteredChanged(); break;
        case 12: _t->powerManagementServiceErrorReasonChanged(); break;
        case 13: _t->load(); break;
        case 14: _t->save(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PowerKCM::*)()>(_a, &PowerKCM::supportedActionsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerKCM::*)()>(_a, &PowerKCM::currentProfileChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerKCM::*)()>(_a, &PowerKCM::supportsBatteryProfilesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerKCM::*)()>(_a, &PowerKCM::isPowerSupplyBatteryPresentChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerKCM::*)()>(_a, &PowerKCM::isPeripheralBatteryPresentChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerKCM::*)()>(_a, &PowerKCM::isLidPresentChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerKCM::*)()>(_a, &PowerKCM::isPowerButtonPresentChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerKCM::*)()>(_a, &PowerKCM::isBatteryConservationModeSupportedChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerKCM::*)()>(_a, &PowerKCM::isChargeStartThresholdSupportedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerKCM::*)()>(_a, &PowerKCM::isChargeStopThresholdSupportedChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerKCM::*)()>(_a, &PowerKCM::chargeStopThresholdMightNeedReconnectChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerKCM::*)()>(_a, &PowerKCM::powerManagementServiceRegisteredChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerKCM::*)()>(_a, &PowerKCM::powerManagementServiceErrorReasonChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariantMap*>(_v) = _t->supportedActions(); break;
        case 1: *reinterpret_cast<QObject**>(_v) = _t->settings(); break;
        case 2: *reinterpret_cast<QObject**>(_v) = _t->externalServiceSettings(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->currentProfile(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->supportsBatteryProfiles(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isPowerSupplyBatteryPresent(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isPeripheralBatteryPresent(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isLidPresent(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isPowerButtonPresent(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isBatteryConservationModeSupported(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isChargeStartThresholdSupported(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isChargeStopThresholdSupported(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->chargeStopThresholdMightNeedReconnect(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->powerManagementServiceRegistered(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->powerManagementServiceErrorReason(); break;
        case 15: *reinterpret_cast<QObject**>(_v) = _t->autoSuspendActionModel(); break;
        case 16: *reinterpret_cast<QObject**>(_v) = _t->batteryCriticalActionModel(); break;
        case 17: *reinterpret_cast<QObject**>(_v) = _t->powerButtonActionModel(); break;
        case 18: *reinterpret_cast<QObject**>(_v) = _t->lidActionModel(); break;
        case 19: *reinterpret_cast<QObject**>(_v) = _t->sleepModeModel(); break;
        case 20: *reinterpret_cast<QObject**>(_v) = _t->powerProfileModel(); break;
        default: break;
        }
    }
}

const QMetaObject *PowerDevil::PowerKCM::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDevil::PowerKCM::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil8PowerKCME_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int PowerDevil::PowerKCM::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void PowerDevil::PowerKCM::supportedActionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PowerDevil::PowerKCM::currentProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PowerDevil::PowerKCM::supportsBatteryProfilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PowerDevil::PowerKCM::isPowerSupplyBatteryPresentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PowerDevil::PowerKCM::isPeripheralBatteryPresentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PowerDevil::PowerKCM::isLidPresentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PowerDevil::PowerKCM::isPowerButtonPresentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PowerDevil::PowerKCM::isBatteryConservationModeSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PowerDevil::PowerKCM::isChargeStartThresholdSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PowerDevil::PowerKCM::isChargeStopThresholdSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void PowerDevil::PowerKCM::chargeStopThresholdMightNeedReconnectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void PowerDevil::PowerKCM::powerManagementServiceRegisteredChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void PowerDevil::PowerKCM::powerManagementServiceErrorReasonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
