/****************************************************************************
** Meta object code from reading C++ file 'powerdevilpolicyagent.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../powerdevil-6.6.91/daemon/powerdevilpolicyagent.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powerdevilpolicyagent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PowerDevil11PolicyAgentE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::PolicyAgent::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevil11PolicyAgentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil::PolicyAgent",
        "D-Bus Interface",
        "org.kde.Solid.PowerManagement.PolicyAgent",
        "dbusPropertiesChanged",
        "",
        "props",
        "InhibitionsChanged",
        "QList<QStringList>",
        "added",
        "removed",
        "unavailablePoliciesChanged",
        "PowerDevil::PolicyAgent::RequiredPolicies",
        "newpolicies",
        "sessionActiveChanged",
        "active",
        "screenLockerActiveChanged",
        "inhibitionAllowedChanged",
        "RequestedInhibitionId",
        "requested",
        "allowed",
        "AddInhibition",
        "types",
        "who",
        "why",
        "ReleaseInhibition",
        "cookie",
        "retainCookie",
        "HasInhibition",
        "releaseAllInhibitions",
        "SetInhibitionAllowed",
        "onServiceUnregistered",
        "serviceName",
        "onSessionHandlerRegistered",
        "onSessionHandlerUnregistered",
        "onActiveSessionChanged",
        "ifaceName",
        "QVariantMap",
        "changedProps",
        "invalidatedProps",
        "activeSession",
        "onManagerPropertyChanged",
        "RequestedInhibitions",
        "QList<PolicyAgentInhibition>",
        "ActiveInhibitions"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dbusPropertiesChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 5 },
        }}),
        // Signal 'InhibitionsChanged'
        QtMocHelpers::SignalData<void(const QList<QStringList> &, const QStringList &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QStringList, 9 },
        }}),
        // Signal 'unavailablePoliciesChanged'
        QtMocHelpers::SignalData<void(PowerDevil::PolicyAgent::RequiredPolicies)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'sessionActiveChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'screenLockerActiveChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'inhibitionAllowedChanged'
        QtMocHelpers::SignalData<void(const RequestedInhibitionId &, bool)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Bool, 19 },
        }}),
        // Slot 'AddInhibition'
        QtMocHelpers::SlotData<uint(uint, const QString &, const QString &)>(20, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { QMetaType::UInt, 21 }, { QMetaType::QString, 22 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'ReleaseInhibition'
        QtMocHelpers::SlotData<void(uint, bool)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'ReleaseInhibition'
        QtMocHelpers::SlotData<void(uint)>(24, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::UInt, 25 },
        }}),
        // Slot 'HasInhibition'
        QtMocHelpers::SlotData<bool(uint)>(27, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 21 },
        }}),
        // Slot 'releaseAllInhibitions'
        QtMocHelpers::SlotData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetInhibitionAllowed'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 23 }, { QMetaType::Bool, 19 },
        }}),
        // Slot 'onServiceUnregistered'
        QtMocHelpers::SlotData<void(const QString &)>(30, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'onSessionHandlerRegistered'
        QtMocHelpers::SlotData<void(const QString &)>(32, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'onSessionHandlerUnregistered'
        QtMocHelpers::SlotData<void(const QString &)>(33, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'onActiveSessionChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, const QStringList &)>(34, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 35 }, { 0x80000000 | 36, 37 }, { QMetaType::QStringList, 38 },
        }}),
        // Slot 'onActiveSessionChanged'
        QtMocHelpers::SlotData<void(const QString &)>(34, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 39 },
        }}),
        // Slot 'onManagerPropertyChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, const QStringList &)>(40, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 35 }, { 0x80000000 | 36, 37 }, { QMetaType::QStringList, 38 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'RequestedInhibitions'
        QtMocHelpers::PropertyData<QList<PolicyAgentInhibition>>(41, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'ActiveInhibitions'
        QtMocHelpers::PropertyData<QList<PolicyAgentInhibition>>(43, 0x80000000 | 42, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PolicyAgent, qt_meta_tag_ZN10PowerDevil11PolicyAgentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PowerDevil::PolicyAgent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil11PolicyAgentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil11PolicyAgentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerDevil11PolicyAgentE_t>.metaTypes,
    nullptr
} };

void PowerDevil::PolicyAgent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PolicyAgent *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dbusPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 1: _t->InhibitionsChanged((*reinterpret_cast<std::add_pointer_t<QList<QStringList>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 2: _t->unavailablePoliciesChanged((*reinterpret_cast<std::add_pointer_t<PowerDevil::PolicyAgent::RequiredPolicies>>(_a[1]))); break;
        case 3: _t->sessionActiveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->screenLockerActiveChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->inhibitionAllowedChanged((*reinterpret_cast<std::add_pointer_t<RequestedInhibitionId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: { uint _r = _t->AddInhibition((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->ReleaseInhibition((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->ReleaseInhibition((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 9: { bool _r = _t->HasInhibition((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->releaseAllInhibitions(); break;
        case 11: _t->SetInhibitionAllowed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 12: _t->onServiceUnregistered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->onSessionHandlerRegistered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->onSessionHandlerUnregistered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->onActiveSessionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 16: _t->onActiveSessionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->onManagerPropertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QStringList> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PolicyAgent::*)(const QStringList & )>(_a, &PolicyAgent::dbusPropertiesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolicyAgent::*)(const QList<QStringList> & , const QStringList & )>(_a, &PolicyAgent::InhibitionsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolicyAgent::*)(PowerDevil::PolicyAgent::RequiredPolicies )>(_a, &PolicyAgent::unavailablePoliciesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolicyAgent::*)(bool )>(_a, &PolicyAgent::sessionActiveChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolicyAgent::*)(bool )>(_a, &PolicyAgent::screenLockerActiveChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PolicyAgent::*)(const RequestedInhibitionId & , bool )>(_a, &PolicyAgent::inhibitionAllowedChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<PolicyAgentInhibition>*>(_v) = _t->listRequestedInhibitions(); break;
        case 1: *reinterpret_cast<QList<PolicyAgentInhibition>*>(_v) = _t->listActiveInhibitions(); break;
        default: break;
        }
    }
}

const QMetaObject *PowerDevil::PolicyAgent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDevil::PolicyAgent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil11PolicyAgentE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int PowerDevil::PolicyAgent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void PowerDevil::PolicyAgent::dbusPropertiesChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PowerDevil::PolicyAgent::InhibitionsChanged(const QList<QStringList> & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void PowerDevil::PolicyAgent::unavailablePoliciesChanged(PowerDevil::PolicyAgent::RequiredPolicies _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PowerDevil::PolicyAgent::sessionActiveChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PowerDevil::PolicyAgent::screenLockerActiveChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PowerDevil::PolicyAgent::inhibitionAllowedChanged(const RequestedInhibitionId & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}
QT_WARNING_POP
