/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Solid.PowerManagement.PolicyAgent.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "powermanagementpolicyagentadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class PowerManagementPolicyAgentAdaptor
 */

PowerManagementPolicyAgentAdaptor::PowerManagementPolicyAgentAdaptor(PowerDevil::PolicyAgent *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

PowerManagementPolicyAgentAdaptor::~PowerManagementPolicyAgentAdaptor()
{
    // destructor
}

QList<PolicyAgentInhibition> PowerManagementPolicyAgentAdaptor::activeInhibitions() const
{
    // get the value of property ActiveInhibitions
    return qvariant_cast< QList<PolicyAgentInhibition> >(parent()->property("ActiveInhibitions"));
}

QList<PolicyAgentInhibition> PowerManagementPolicyAgentAdaptor::requestedInhibitions() const
{
    // get the value of property RequestedInhibitions
    return qvariant_cast< QList<PolicyAgentInhibition> >(parent()->property("RequestedInhibitions"));
}

uint PowerManagementPolicyAgentAdaptor::AddInhibition(uint types, const QString &app_name, const QString &reason)
{
    // handle method call org.kde.Solid.PowerManagement.PolicyAgent.AddInhibition
    return parent()->AddInhibition(types, app_name, reason);
}

bool PowerManagementPolicyAgentAdaptor::HasInhibition(uint types)
{
    // handle method call org.kde.Solid.PowerManagement.PolicyAgent.HasInhibition
    return parent()->HasInhibition(types);
}

QList<QStringList> PowerManagementPolicyAgentAdaptor::ListInhibitions()
{
    // handle method call org.kde.Solid.PowerManagement.PolicyAgent.ListInhibitions
    return parent()->ListInhibitions();
}

void PowerManagementPolicyAgentAdaptor::ReleaseInhibition(uint cookie)
{
    // handle method call org.kde.Solid.PowerManagement.PolicyAgent.ReleaseInhibition
    parent()->ReleaseInhibition(cookie);
}

void PowerManagementPolicyAgentAdaptor::SetInhibitionAllowed(const QString &who, const QString &why, bool allowed)
{
    // handle method call org.kde.Solid.PowerManagement.PolicyAgent.SetInhibitionAllowed
    parent()->SetInhibitionAllowed(who, why, allowed);
}


#include "moc_powermanagementpolicyagentadaptor.cpp"
