/****************************************************************************
** Meta object code from reading C++ file 'screenbrightnesscontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../powerdevil-6.6.91/daemon/controllers/screenbrightnesscontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'screenbrightnesscontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26ScreenBrightnessControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenBrightnessController::qt_create_metaobjectdata<qt_meta_tag_ZN26ScreenBrightnessControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenBrightnessController",
        "detectionFinished",
        "",
        "displayIdsChanged",
        "displayIds",
        "displayAdded",
        "displayId",
        "displayRemoved",
        "brightnessChanged",
        "PowerDevil::BrightnessLogic::BrightnessInfo",
        "sourceClientName",
        "sourceClientContext",
        "IndicatorHint",
        "legacyDisplayIdsChanged",
        "legacyBrightnessInfoChanged",
        "onDisplayDestroyed",
        "onDetectorDisplaysChanged",
        "onExternalBrightnessChangeObserved",
        "DisplayBrightness*",
        "display",
        "value"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'detectionFinished'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayIdsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 4 },
        }}),
        // Signal 'displayAdded'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'displayRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'brightnessChanged'
        QtMocHelpers::SignalData<void(const QString &, const PowerDevil::BrightnessLogic::BrightnessInfo &, const QString &, const QString &, enum IndicatorHint)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 9, 2 }, { QMetaType::QString, 10 }, { QMetaType::QString, 11 },
            { 0x80000000 | 12, 2 },
        }}),
        // Signal 'legacyDisplayIdsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 },
        }}),
        // Signal 'legacyBrightnessInfoChanged'
        QtMocHelpers::SignalData<void(const PowerDevil::BrightnessLogic::BrightnessInfo &, enum IndicatorHint)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { 0x80000000 | 12, 2 },
        }}),
        // Slot 'onDisplayDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 2 },
        }}),
        // Slot 'onDetectorDisplaysChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onExternalBrightnessChangeObserved'
        QtMocHelpers::SlotData<void(DisplayBrightness *, int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::Int, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenBrightnessController, qt_meta_tag_ZN26ScreenBrightnessControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenBrightnessController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26ScreenBrightnessControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26ScreenBrightnessControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26ScreenBrightnessControllerE_t>.metaTypes,
    nullptr
} };

void ScreenBrightnessController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenBrightnessController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->detectionFinished(); break;
        case 1: _t->displayIdsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->displayAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->displayRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->brightnessChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<PowerDevil::BrightnessLogic::BrightnessInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<enum IndicatorHint>>(_a[5]))); break;
        case 5: _t->legacyDisplayIdsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 6: _t->legacyBrightnessInfoChanged((*reinterpret_cast<std::add_pointer_t<PowerDevil::BrightnessLogic::BrightnessInfo>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum IndicatorHint>>(_a[2]))); break;
        case 7: _t->onDisplayDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 8: _t->onDetectorDisplaysChanged(); break;
        case 9: _t->onExternalBrightnessChangeObserved((*reinterpret_cast<std::add_pointer_t<DisplayBrightness*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DisplayBrightness* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessController::*)()>(_a, &ScreenBrightnessController::detectionFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessController::*)(const QStringList & )>(_a, &ScreenBrightnessController::displayIdsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessController::*)(const QString & )>(_a, &ScreenBrightnessController::displayAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessController::*)(const QString & )>(_a, &ScreenBrightnessController::displayRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessController::*)(const QString & , const PowerDevil::BrightnessLogic::BrightnessInfo & , const QString & , const QString & , IndicatorHint )>(_a, &ScreenBrightnessController::brightnessChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessController::*)(const QStringList & )>(_a, &ScreenBrightnessController::legacyDisplayIdsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessController::*)(const PowerDevil::BrightnessLogic::BrightnessInfo & , IndicatorHint )>(_a, &ScreenBrightnessController::legacyBrightnessInfoChanged, 6))
            return;
    }
}

const QMetaObject *ScreenBrightnessController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenBrightnessController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26ScreenBrightnessControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ScreenBrightnessController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void ScreenBrightnessController::detectionFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ScreenBrightnessController::displayIdsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ScreenBrightnessController::displayAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ScreenBrightnessController::displayRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ScreenBrightnessController::brightnessChanged(const QString & _t1, const PowerDevil::BrightnessLogic::BrightnessInfo & _t2, const QString & _t3, const QString & _t4, IndicatorHint _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 5
void ScreenBrightnessController::legacyDisplayIdsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ScreenBrightnessController::legacyBrightnessInfoChanged(const PowerDevil::BrightnessLogic::BrightnessInfo & _t1, IndicatorHint _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}
QT_WARNING_POP
