/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.UPower.PowerProfiles.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef POWER_PROFILES_INTERFACE_H
#define POWER_PROFILES_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.UPower.PowerProfiles
 */
class OrgFreedesktopUPowerPowerProfilesInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.UPower.PowerProfiles"; }

public:
    OrgFreedesktopUPowerPowerProfilesInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopUPowerPowerProfilesInterface();

    Q_PROPERTY(QStringList Actions READ actions)
    inline QStringList actions() const
    { return qvariant_cast< QStringList >(property("Actions")); }

    Q_PROPERTY(QString ActiveProfile READ activeProfile WRITE setActiveProfile)
    inline QString activeProfile() const
    { return qvariant_cast< QString >(property("ActiveProfile")); }
    inline void setActiveProfile(const QString &value)
    { setProperty("ActiveProfile", QVariant::fromValue(value)); }

    Q_PROPERTY(QList<QVariantMap> ActiveProfileHolds READ activeProfileHolds)
    inline QList<QVariantMap> activeProfileHolds() const
    { return qvariant_cast< QList<QVariantMap> >(property("ActiveProfileHolds")); }

    Q_PROPERTY(QString PerformanceDegraded READ performanceDegraded)
    inline QString performanceDegraded() const
    { return qvariant_cast< QString >(property("PerformanceDegraded")); }

    Q_PROPERTY(QString PerformanceInhibited READ performanceInhibited)
    inline QString performanceInhibited() const
    { return qvariant_cast< QString >(property("PerformanceInhibited")); }

    Q_PROPERTY(QList<QVariantMap> Profiles READ profiles)
    inline QList<QVariantMap> profiles() const
    { return qvariant_cast< QList<QVariantMap> >(property("Profiles")); }

    Q_PROPERTY(QString Version READ version)
    inline QString version() const
    { return qvariant_cast< QString >(property("Version")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<uint> HoldProfile(const QString &profile, const QString &reason, const QString &application_id)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(profile) << QVariant::fromValue(reason) << QVariant::fromValue(application_id);
        return asyncCallWithArgumentList(QStringLiteral("HoldProfile"), argumentList);
    }

    inline QDBusPendingReply<> ReleaseProfile(uint cookie)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(cookie);
        return asyncCallWithArgumentList(QStringLiteral("ReleaseProfile"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void ProfileReleased(uint cookie);
};

namespace org {
  namespace freedesktop {
    namespace UPower {
      using PowerProfiles = ::OrgFreedesktopUPowerPowerProfilesInterface;
    }
  }
}

#endif
