/****************************************************************************
** Meta object code from reading C++ file 'powerdevilfdoconnector.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../powerdevil-6.6.91/daemon/powerdevilfdoconnector.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powerdevilfdoconnector.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PowerDevil12FdoConnectorE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::FdoConnector::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevil12FdoConnectorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil::FdoConnector",
        "D-Bus Interface",
        "org.freedesktop.PowerManagement",
        "org.freedesktop.PowerManagement.Inhibit",
        "CanSuspendChanged",
        "",
        "canSuspend",
        "CanHibernateChanged",
        "canHibernate",
        "CanHybridSuspendChanged",
        "canHybridSuspend",
        "CanSuspendThenHibernateChanged",
        "canSuspendThenHibernate",
        "PowerSaveStatusChanged",
        "savePower",
        "HasInhibitChanged",
        "hasInhibit",
        "onAcAdapterStateChanged",
        "BatteryController::AcAdapterState",
        "onUnavailablePoliciesChanged",
        "PowerDevil::PolicyAgent::RequiredPolicies",
        "triggerSuspendSession",
        "PowerDevil::PowerButtonAction",
        "action"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'CanSuspendChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'CanHibernateChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'CanHybridSuspendChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'CanSuspendThenHibernateChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'PowerSaveStatusChanged'
        QtMocHelpers::SignalData<void(bool)>(13, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'HasInhibitChanged'
        QtMocHelpers::SignalData<void(bool)>(15, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Slot 'onAcAdapterStateChanged'
        QtMocHelpers::SlotData<void(BatteryController::AcAdapterState)>(17, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 18, 5 },
        }}),
        // Slot 'onUnavailablePoliciesChanged'
        QtMocHelpers::SlotData<void(PowerDevil::PolicyAgent::RequiredPolicies)>(19, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 5 },
        }}),
        // Slot 'triggerSuspendSession'
        QtMocHelpers::SlotData<void(PowerDevil::PowerButtonAction)>(21, 5, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    1,    3 },
    });
    return QtMocHelpers::metaObjectData<FdoConnector, qt_meta_tag_ZN10PowerDevil12FdoConnectorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PowerDevil::FdoConnector::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil12FdoConnectorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil12FdoConnectorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerDevil12FdoConnectorE_t>.metaTypes,
    nullptr
} };

void PowerDevil::FdoConnector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FdoConnector *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CanSuspendChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->CanHibernateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->CanHybridSuspendChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->CanSuspendThenHibernateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->PowerSaveStatusChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->HasInhibitChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->onAcAdapterStateChanged((*reinterpret_cast<std::add_pointer_t<BatteryController::AcAdapterState>>(_a[1]))); break;
        case 7: _t->onUnavailablePoliciesChanged((*reinterpret_cast<std::add_pointer_t<PowerDevil::PolicyAgent::RequiredPolicies>>(_a[1]))); break;
        case 8: _t->triggerSuspendSession((*reinterpret_cast<std::add_pointer_t<PowerDevil::PowerButtonAction>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FdoConnector::*)(bool )>(_a, &FdoConnector::CanSuspendChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FdoConnector::*)(bool )>(_a, &FdoConnector::CanHibernateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FdoConnector::*)(bool )>(_a, &FdoConnector::CanHybridSuspendChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FdoConnector::*)(bool )>(_a, &FdoConnector::CanSuspendThenHibernateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FdoConnector::*)(bool )>(_a, &FdoConnector::PowerSaveStatusChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FdoConnector::*)(bool )>(_a, &FdoConnector::HasInhibitChanged, 5))
            return;
    }
}

const QMetaObject *PowerDevil::FdoConnector::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDevil::FdoConnector::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil12FdoConnectorE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int PowerDevil::FdoConnector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void PowerDevil::FdoConnector::CanSuspendChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PowerDevil::FdoConnector::CanHibernateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PowerDevil::FdoConnector::CanHybridSuspendChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PowerDevil::FdoConnector::CanSuspendThenHibernateChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PowerDevil::FdoConnector::PowerSaveStatusChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PowerDevil::FdoConnector::HasInhibitChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
