/****************************************************************************
** Meta object code from reading C++ file 'screenbrightnessdisplayadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "screenbrightnessdisplayadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'screenbrightnessdisplayadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN30ScreenBrightnessDisplayAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenBrightnessDisplayAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN30ScreenBrightnessDisplayAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenBrightnessDisplayAdaptor",
        "D-Bus Interface",
        "org.kde.ScreenBrightness.Display",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.ScreenBrightness.Display\">\n    <prop"
        "erty access=\"read\" type=\"s\" name=\"Label\">\n    </property>\n"
        "    <property access=\"read\" type=\"b\" name=\"IsInternal\">\n   "
        " </property>\n    <property access=\"read\" type=\"i\" name=\"MaxB"
        "rightness\">\n    </property>\n    <property access=\"read\" type="
        "\"i\" name=\"Brightness\">\n    </property>\n    <method name=\"Se"
        "tBrightness\">\n      <arg direction=\"in\" type=\"i\" name=\"brig"
        "htness\"/>\n      <arg direction=\"in\" type=\"u\" name=\"flags\"/"
        ">\n    </method>\n    <method name=\"SetBrightnessWithContext\">\n"
        "      <arg direction=\"in\" type=\"i\" name=\"brightness\"/>\n    "
        "  <arg direction=\"in\" type=\"u\" name=\"flags\"/>\n      <arg di"
        "rection=\"in\" type=\"s\" name=\"source_client_context\"/>\n    </"
        "method>\n  </interface>\n",
        "SetBrightness",
        "",
        "brightness",
        "flags",
        "SetBrightnessWithContext",
        "source_client_context",
        "Brightness",
        "IsInternal",
        "Label",
        "MaxBrightness"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'SetBrightness'
        QtMocHelpers::SlotData<void(int, uint)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::UInt, 8 },
        }}),
        // Slot 'SetBrightnessWithContext'
        QtMocHelpers::SlotData<void(int, uint, const QString &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { QMetaType::UInt, 8 }, { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Brightness'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'IsInternal'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Label'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'MaxBrightness'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ScreenBrightnessDisplayAdaptor, qt_meta_tag_ZN30ScreenBrightnessDisplayAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ScreenBrightnessDisplayAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30ScreenBrightnessDisplayAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30ScreenBrightnessDisplayAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30ScreenBrightnessDisplayAdaptorE_t>.metaTypes,
    nullptr
} };

void ScreenBrightnessDisplayAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenBrightnessDisplayAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->SetBrightness((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 1: _t->SetBrightnessWithContext((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->brightness(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isInternal(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->maxBrightness(); break;
        default: break;
        }
    }
}

const QMetaObject *ScreenBrightnessDisplayAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenBrightnessDisplayAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30ScreenBrightnessDisplayAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int ScreenBrightnessDisplayAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
