// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "batterymonitor_debug.h"

 namespace APPLETS {
Q_LOGGING_CATEGORY(BATTERYMONITOR, "org.kde.applets.batterymonitor", QtInfoMsg)
} 
