/****************************************************************************
** Meta object code from reading C++ file 'powerdevilenums.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../powerdevil-6.6.91/daemon/powerdevilenums.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powerdevilenums.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PowerDevilE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevilE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil",
        "RegisterEnumClassesUnscoped",
        "false",
        "PowerButtonAction",
        "NoAction",
        "Sleep",
        "Hibernate",
        "Shutdown",
        "PromptLogoutDialog",
        "LockScreen",
        "TurnOffScreen",
        "ToggleScreenOnOff",
        "SleepMode",
        "SuspendToRam",
        "HybridSuspend",
        "SuspendThenHibernate",
        "BrightnessControlType",
        "UnknownBrightnessControl",
        "Screen",
        "Keyboard"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PowerButtonAction'
        QtMocHelpers::EnumData<PowerButtonAction>(3, 3, QMC::EnumIsScoped).add({
            {    4, PowerButtonAction::NoAction },
            {    5, PowerButtonAction::Sleep },
            {    6, PowerButtonAction::Hibernate },
            {    7, PowerButtonAction::Shutdown },
            {    8, PowerButtonAction::PromptLogoutDialog },
            {    9, PowerButtonAction::LockScreen },
            {   10, PowerButtonAction::TurnOffScreen },
            {   11, PowerButtonAction::ToggleScreenOnOff },
        }),
        // enum 'SleepMode'
        QtMocHelpers::EnumData<SleepMode>(12, 12, QMC::EnumIsScoped).add({
            {   13, SleepMode::SuspendToRam },
            {   14, SleepMode::HybridSuspend },
            {   15, SleepMode::SuspendThenHibernate },
        }),
        // enum 'BrightnessControlType'
        QtMocHelpers::EnumData<BrightnessControlType>(16, 16, QMC::EnumIsScoped).add({
            {   17, BrightnessControlType::UnknownBrightnessControl },
            {   18, BrightnessControlType::Screen },
            {   19, BrightnessControlType::Keyboard },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN10PowerDevilE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN10PowerDevilE =
    PowerDevil::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevilE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN10PowerDevilE =
    qt_staticMetaObjectContent_ZN10PowerDevilE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN10PowerDevilE =
    qt_staticMetaObjectContent_ZN10PowerDevilE.relocatingData;

Q_CONSTINIT const QMetaObject PowerDevil::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN10PowerDevilE.stringdata,
    qt_staticMetaObjectStaticContent_ZN10PowerDevilE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN10PowerDevilE.metaTypes,
    nullptr
} };

QT_WARNING_POP
