/****************************************************************************
** Meta object code from reading C++ file 'powerdevilscreenbrightnessagent.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../powerdevil-6.6.91/daemon/powerdevilscreenbrightnessagent.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powerdevilscreenbrightnessagent.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PowerDevil23ScreenBrightnessDisplayE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::ScreenBrightnessDisplay::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevil23ScreenBrightnessDisplayE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil::ScreenBrightnessDisplay",
        "D-Bus Interface",
        "org.kde.ScreenBrightness.Display",
        "DBusName",
        "Label",
        "IsInternal",
        "Brightness",
        "MaxBrightness"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'DBusName'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'Label'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IsInternal'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'Brightness'
        QtMocHelpers::PropertyData<int>(6, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'MaxBrightness'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ScreenBrightnessDisplay, qt_meta_tag_ZN10PowerDevil23ScreenBrightnessDisplayE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PowerDevil::ScreenBrightnessDisplay::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil23ScreenBrightnessDisplayE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil23ScreenBrightnessDisplayE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerDevil23ScreenBrightnessDisplayE_t>.metaTypes,
    nullptr
} };

void PowerDevil::ScreenBrightnessDisplay::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenBrightnessDisplay *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->DBusName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->Label(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->IsInternal(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->Brightness(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->MaxBrightness(); break;
        default: break;
        }
    }
}

const QMetaObject *PowerDevil::ScreenBrightnessDisplay::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDevil::ScreenBrightnessDisplay::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil23ScreenBrightnessDisplayE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int PowerDevil::ScreenBrightnessDisplay::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN10PowerDevil21ScreenBrightnessAgentE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::ScreenBrightnessAgent::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevil21ScreenBrightnessAgentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil::ScreenBrightnessAgent",
        "D-Bus Interface",
        "org.kde.ScreenBrightness",
        "DisplayAdded",
        "",
        "displayId",
        "DisplayRemoved",
        "BrightnessChanged",
        "brightness",
        "sourceClientName",
        "sourceClientContext",
        "BrightnessRangeChanged",
        "maxBrightness",
        "AdjustBrightnessRatio",
        "delta",
        "flags",
        "AdjustBrightnessRatioWithContext",
        "AdjustBrightnessStep",
        "stepAction",
        "AdjustBrightnessStepWithContext",
        "stepDelta",
        "onBrightnessChanged",
        "BrightnessLogic::BrightnessInfo",
        "brightnessInfo",
        "ScreenBrightnessController::IndicatorHint",
        "hint",
        "onBrightnessRangeChanged",
        "actOnBrightnessKey",
        "BrightnessLogic::StepAdjustmentAction",
        "action",
        "DisplaysDBusNames"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'DisplayAdded'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'DisplayRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'BrightnessChanged'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &, const QString &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 8 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'BrightnessRangeChanged'
        QtMocHelpers::SignalData<void(const QString &, int, int)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 12 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'AdjustBrightnessRatio'
        QtMocHelpers::SlotData<void(double, uint)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 14 }, { QMetaType::UInt, 15 },
        }}),
        // Slot 'AdjustBrightnessRatio'
        QtMocHelpers::SlotData<void(double)>(13, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Double, 14 },
        }}),
        // Slot 'AdjustBrightnessRatioWithContext'
        QtMocHelpers::SlotData<void(double, uint, const QString &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 14 }, { QMetaType::UInt, 15 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'AdjustBrightnessStep'
        QtMocHelpers::SlotData<void(uint, uint)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 18 }, { QMetaType::UInt, 15 },
        }}),
        // Slot 'AdjustBrightnessStep'
        QtMocHelpers::SlotData<void(uint)>(17, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::UInt, 18 },
        }}),
        // Slot 'AdjustBrightnessStepWithContext'
        QtMocHelpers::SlotData<void(uint, uint, const QString &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 20 }, { QMetaType::UInt, 15 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'onBrightnessChanged'
        QtMocHelpers::SlotData<void(const QString &, const BrightnessLogic::BrightnessInfo &, const QString &, const QString &, ScreenBrightnessController::IndicatorHint)>(21, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 22, 23 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'onBrightnessRangeChanged'
        QtMocHelpers::SlotData<void(const QString &, const BrightnessLogic::BrightnessInfo &)>(26, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'actOnBrightnessKey'
        QtMocHelpers::SlotData<void(BrightnessLogic::StepAdjustmentAction)>(27, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'DisplaysDBusNames'
        QtMocHelpers::PropertyData<QStringList>(30, QMetaType::QStringList, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ScreenBrightnessAgent, qt_meta_tag_ZN10PowerDevil21ScreenBrightnessAgentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PowerDevil::ScreenBrightnessAgent::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil21ScreenBrightnessAgentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil21ScreenBrightnessAgentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerDevil21ScreenBrightnessAgentE_t>.metaTypes,
    nullptr
} };

void PowerDevil::ScreenBrightnessAgent::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenBrightnessAgent *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->DisplayAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->DisplayRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->BrightnessChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 3: _t->BrightnessRangeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->AdjustBrightnessRatio((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 5: _t->AdjustBrightnessRatio((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->AdjustBrightnessRatioWithContext((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->AdjustBrightnessStep((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 8: _t->AdjustBrightnessStep((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 9: _t->AdjustBrightnessStepWithContext((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 10: _t->onBrightnessChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<BrightnessLogic::BrightnessInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<ScreenBrightnessController::IndicatorHint>>(_a[5]))); break;
        case 11: _t->onBrightnessRangeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<BrightnessLogic::BrightnessInfo>>(_a[2]))); break;
        case 12: _t->actOnBrightnessKey((*reinterpret_cast<std::add_pointer_t<BrightnessLogic::StepAdjustmentAction>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessAgent::*)(const QString & )>(_a, &ScreenBrightnessAgent::DisplayAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessAgent::*)(const QString & )>(_a, &ScreenBrightnessAgent::DisplayRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessAgent::*)(const QString & , int , const QString & , const QString & )>(_a, &ScreenBrightnessAgent::BrightnessChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenBrightnessAgent::*)(const QString & , int , int )>(_a, &ScreenBrightnessAgent::BrightnessRangeChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->DisplaysDBusNames(); break;
        default: break;
        }
    }
}

const QMetaObject *PowerDevil::ScreenBrightnessAgent::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDevil::ScreenBrightnessAgent::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil21ScreenBrightnessAgentE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int PowerDevil::ScreenBrightnessAgent::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void PowerDevil::ScreenBrightnessAgent::DisplayAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PowerDevil::ScreenBrightnessAgent::DisplayRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PowerDevil::ScreenBrightnessAgent::BrightnessChanged(const QString & _t1, int _t2, const QString & _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 3
void PowerDevil::ScreenBrightnessAgent::BrightnessRangeChanged(const QString & _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
