/****************************************************************************
** Meta object code from reading C++ file 'powerprofile.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../powerdevil-6.6.91/daemon/actions/bundled/powerprofile.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'powerprofile.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PowerDevil14BundledActions12PowerProfileE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::BundledActions::PowerProfile::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevil14BundledActions12PowerProfileE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil::BundledActions::PowerProfile",
        "D-Bus Interface",
        "org.kde.Solid.PowerManagement.Actions.PowerProfile",
        "currentProfileChanged",
        "",
        "profile",
        "profileChoicesChanged",
        "profiles",
        "performanceInhibitedReasonChanged",
        "reason",
        "performanceDegradedReasonChanged",
        "profileHoldsChanged",
        "QList<QVariantMap>",
        "holds",
        "configuredProfileChanged",
        "propertiesChanged",
        "interface",
        "QVariantMap",
        "changed",
        "invalidated",
        "profileChoices",
        "configuredProfile",
        "currentProfile"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentProfileChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'profileChoicesChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Signal 'performanceInhibitedReasonChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'performanceDegradedReasonChanged'
        QtMocHelpers::SignalData<void(const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'profileHoldsChanged'
        QtMocHelpers::SignalData<void(const QList<QVariantMap> &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'configuredProfileChanged'
        QtMocHelpers::SignalData<void(const QString &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'propertiesChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, const QStringList &)>(15, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 }, { QMetaType::QStringList, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'profileChoices'
        QtMocHelpers::PropertyData<QStringList>(20, QMetaType::QStringList, QMC::DefaultPropertyFlags, 1),
        // property 'configuredProfile'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'currentProfile'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PowerProfile, qt_meta_tag_ZN10PowerDevil14BundledActions12PowerProfileE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PowerDevil::BundledActions::PowerProfile::staticMetaObject = { {
    QMetaObject::SuperData::link<PowerDevil::Action::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil14BundledActions12PowerProfileE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil14BundledActions12PowerProfileE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerDevil14BundledActions12PowerProfileE_t>.metaTypes,
    nullptr
} };

void PowerDevil::BundledActions::PowerProfile::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PowerProfile *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentProfileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->profileChoicesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->performanceInhibitedReasonChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->performanceDegradedReasonChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->profileHoldsChanged((*reinterpret_cast<std::add_pointer_t<QList<QVariantMap>>>(_a[1]))); break;
        case 5: _t->configuredProfileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->propertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PowerProfile::*)(const QString & )>(_a, &PowerProfile::currentProfileChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfile::*)(const QStringList & )>(_a, &PowerProfile::profileChoicesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfile::*)(const QString & )>(_a, &PowerProfile::performanceInhibitedReasonChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfile::*)(const QString & )>(_a, &PowerProfile::performanceDegradedReasonChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfile::*)(const QList<QVariantMap> & )>(_a, &PowerProfile::profileHoldsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PowerProfile::*)(const QString & )>(_a, &PowerProfile::configuredProfileChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->profileChoices(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->configuredProfile(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->currentProfile(); break;
        default: break;
        }
    }
}

const QMetaObject *PowerDevil::BundledActions::PowerProfile::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDevil::BundledActions::PowerProfile::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil14BundledActions12PowerProfileE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return PowerDevil::Action::qt_metacast(_clname);
}

int PowerDevil::BundledActions::PowerProfile::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PowerDevil::Action::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void PowerDevil::BundledActions::PowerProfile::currentProfileChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PowerDevil::BundledActions::PowerProfile::profileChoicesChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void PowerDevil::BundledActions::PowerProfile::performanceInhibitedReasonChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PowerDevil::BundledActions::PowerProfile::performanceDegradedReasonChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PowerDevil::BundledActions::PowerProfile::profileHoldsChanged(const QList<QVariantMap> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void PowerDevil::BundledActions::PowerProfile::configuredProfileChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
