/****************************************************************************
** Meta object code from reading C++ file 'mobilepower.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../powerdevil-6.6.91/kcm_mobile/mobilepower.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mobilepower.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11MobilePowerE_t {};
} // unnamed namespace

template <> constexpr inline auto MobilePower::qt_create_metaobjectdata<qt_meta_tag_ZN11MobilePowerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MobilePower",
        "dimScreenIdxChanged",
        "",
        "screenOffIdxChanged",
        "suspendSessionIdxChanged",
        "powerProfileIdxChanged",
        "isPowerProfileSupportedChanged",
        "timeOptions",
        "batteries",
        "BatteryModel*",
        "dimScreenIdx",
        "screenOffIdx",
        "suspendSessionIdx",
        "powerProfileModel",
        "powerProfileIdx",
        "isPowerProfileSupported"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dimScreenIdxChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenOffIdxChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'suspendSessionIdxChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'powerProfileIdxChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isPowerProfileSupportedChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'timeOptions'
        QtMocHelpers::MethodData<QStringList() const>(7, 2, QMC::AccessPublic, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'batteries'
        QtMocHelpers::PropertyData<BatteryModel*>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'dimScreenIdx'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'screenOffIdx'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'suspendSessionIdx'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'powerProfileModel'
        QtMocHelpers::PropertyData<QObject*>(13, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'powerProfileIdx'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isPowerProfileSupported'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MobilePower, qt_meta_tag_ZN11MobilePowerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MobilePower::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MobilePowerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MobilePowerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11MobilePowerE_t>.metaTypes,
    nullptr
} };

void MobilePower::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MobilePower *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dimScreenIdxChanged(); break;
        case 1: _t->screenOffIdxChanged(); break;
        case 2: _t->suspendSessionIdxChanged(); break;
        case 3: _t->powerProfileIdxChanged(); break;
        case 4: _t->isPowerProfileSupportedChanged(); break;
        case 5: { QStringList _r = _t->timeOptions();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MobilePower::*)()>(_a, &MobilePower::dimScreenIdxChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobilePower::*)()>(_a, &MobilePower::screenOffIdxChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobilePower::*)()>(_a, &MobilePower::suspendSessionIdxChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobilePower::*)()>(_a, &MobilePower::powerProfileIdxChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MobilePower::*)()>(_a, &MobilePower::isPowerProfileSupportedChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BatteryModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<BatteryModel**>(_v) = _t->batteries(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->dimScreenIdx(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->screenOffIdx(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->suspendSessionIdx(); break;
        case 4: *reinterpret_cast<QObject**>(_v) = _t->powerProfileModel(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->powerProfileIdx(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isPowerProfileSupported(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setDimScreenIdx(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setScreenOffIdx(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setSuspendSessionIdx(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setPowerProfileIdx(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MobilePower::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MobilePower::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MobilePowerE_t>.strings))
        return static_cast<void*>(this);
    return KQuickConfigModule::qt_metacast(_clname);
}

int MobilePower::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void MobilePower::dimScreenIdxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MobilePower::screenOffIdxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MobilePower::suspendSessionIdxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MobilePower::powerProfileIdxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MobilePower::isPowerProfileSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
