/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Solid.PowerManagement.Actions.BrightnessControl.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef BRIGHTNESSCONTROLADAPTOR_H
#define BRIGHTNESSCONTROLADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "brightnesscontrol.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.Solid.PowerManagement.Actions.BrightnessControl
 */
class BrightnessControlAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.Solid.PowerManagement.Actions.BrightnessControl")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.Solid.PowerManagement.Actions.BrightnessControl\">\n"
"    <method name=\"setBrightness\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"setBrightnessSilent\">\n"
"      <arg direction=\"in\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"brightness\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"brightnessMax\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"brightnessMin\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <method name=\"knownSafeBrightnessMin\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"    <signal name=\"brightnessChanged\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </signal>\n"
"    <signal name=\"brightnessMaxChanged\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </signal>\n"
"    <signal name=\"brightnessMinChanged\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </signal>\n"
"    <method name=\"brightnessSteps\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    BrightnessControlAdaptor(PowerDevil::BundledActions::BrightnessControl *parent);
    ~BrightnessControlAdaptor() override;

    inline PowerDevil::BundledActions::BrightnessControl *parent() const
    { return static_cast<PowerDevil::BundledActions::BrightnessControl *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    int brightness();
    int brightnessMax();
    int brightnessMin();
    int brightnessSteps();
    int knownSafeBrightnessMin();
    void setBrightness(int in0);
    void setBrightnessSilent(int in0);
Q_SIGNALS: // SIGNALS
    void brightnessChanged(int in0);
    void brightnessMaxChanged(int in0);
    void brightnessMinChanged(int in0);
};

#endif
