/****************************************************************************
** Meta object code from reading C++ file 'ExternalServiceSettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../powerdevil-6.6.91/kcm/ExternalServiceSettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ExternalServiceSettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10PowerDevil23ExternalServiceSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto PowerDevil::ExternalServiceSettings::qt_create_metaobjectdata<qt_meta_tag_ZN10PowerDevil23ExternalServiceSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PowerDevil::ExternalServiceSettings",
        "settingsChanged",
        "",
        "batteryConservationModeChanged",
        "chargeStartThresholdChanged",
        "chargeStopThresholdChanged",
        "isBatteryConservationModeSupportedChanged",
        "isChargeStartThresholdSupportedChanged",
        "isChargeStopThresholdSupportedChanged",
        "chargeStopThresholdMightNeedReconnectChanged",
        "load",
        "QWindow*",
        "parentWindowForKAuth",
        "save",
        "setBatteryConservationMode",
        "setChargeStartThreshold",
        "setChargeStopThreshold",
        "chargeStartThreshold",
        "chargeStopThreshold",
        "batteryConservationMode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'settingsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'batteryConservationModeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'chargeStartThresholdChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'chargeStopThresholdChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isBatteryConservationModeSupportedChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isChargeStartThresholdSupportedChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isChargeStopThresholdSupportedChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'chargeStopThresholdMightNeedReconnectChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void(QWindow *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void(QWindow *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setBatteryConservationMode'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setChargeStartThreshold'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'setChargeStopThreshold'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'chargeStartThreshold'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'chargeStopThreshold'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'batteryConservationMode'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ExternalServiceSettings, qt_meta_tag_ZN10PowerDevil23ExternalServiceSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PowerDevil::ExternalServiceSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil23ExternalServiceSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil23ExternalServiceSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10PowerDevil23ExternalServiceSettingsE_t>.metaTypes,
    nullptr
} };

void PowerDevil::ExternalServiceSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ExternalServiceSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->settingsChanged(); break;
        case 1: _t->batteryConservationModeChanged(); break;
        case 2: _t->chargeStartThresholdChanged(); break;
        case 3: _t->chargeStopThresholdChanged(); break;
        case 4: _t->isBatteryConservationModeSupportedChanged(); break;
        case 5: _t->isChargeStartThresholdSupportedChanged(); break;
        case 6: _t->isChargeStopThresholdSupportedChanged(); break;
        case 7: _t->chargeStopThresholdMightNeedReconnectChanged(); break;
        case 8: _t->load((*reinterpret_cast<std::add_pointer_t<QWindow*>>(_a[1]))); break;
        case 9: _t->load(); break;
        case 10: _t->save((*reinterpret_cast<std::add_pointer_t<QWindow*>>(_a[1]))); break;
        case 11: _t->save(); break;
        case 12: _t->setBatteryConservationMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setChargeStartThreshold((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->setChargeStopThreshold((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ExternalServiceSettings::*)()>(_a, &ExternalServiceSettings::settingsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExternalServiceSettings::*)()>(_a, &ExternalServiceSettings::batteryConservationModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExternalServiceSettings::*)()>(_a, &ExternalServiceSettings::chargeStartThresholdChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExternalServiceSettings::*)()>(_a, &ExternalServiceSettings::chargeStopThresholdChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExternalServiceSettings::*)()>(_a, &ExternalServiceSettings::isBatteryConservationModeSupportedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExternalServiceSettings::*)()>(_a, &ExternalServiceSettings::isChargeStartThresholdSupportedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExternalServiceSettings::*)()>(_a, &ExternalServiceSettings::isChargeStopThresholdSupportedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ExternalServiceSettings::*)()>(_a, &ExternalServiceSettings::chargeStopThresholdMightNeedReconnectChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->chargeStartThreshold(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->chargeStopThreshold(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->batteryConservationMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setChargeStartThreshold(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setChargeStopThreshold(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setBatteryConservationMode(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PowerDevil::ExternalServiceSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PowerDevil::ExternalServiceSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10PowerDevil23ExternalServiceSettingsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PowerDevil::ExternalServiceSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void PowerDevil::ExternalServiceSettings::settingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PowerDevil::ExternalServiceSettings::batteryConservationModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PowerDevil::ExternalServiceSettings::chargeStartThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PowerDevil::ExternalServiceSettings::chargeStopThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PowerDevil::ExternalServiceSettings::isBatteryConservationModeSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PowerDevil::ExternalServiceSettings::isChargeStartThresholdSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PowerDevil::ExternalServiceSettings::isChargeStopThresholdSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PowerDevil::ExternalServiceSettings::chargeStopThresholdMightNeedReconnectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
