/****************************************************************************
** Meta object code from reading C++ file 'power_profiles_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "power_profiles_interface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'power_profiles_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN42OrgFreedesktopUPowerPowerProfilesInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopUPowerPowerProfilesInterface::qt_create_metaobjectdata<qt_meta_tag_ZN42OrgFreedesktopUPowerPowerProfilesInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopUPowerPowerProfilesInterface",
        "ProfileReleased",
        "",
        "cookie",
        "HoldProfile",
        "QDBusPendingReply<uint>",
        "profile",
        "reason",
        "application_id",
        "ReleaseProfile",
        "QDBusPendingReply<>",
        "Actions",
        "ActiveProfile",
        "ActiveProfileHolds",
        "QList<QVariantMap>",
        "PerformanceDegraded",
        "PerformanceInhibited",
        "Profiles",
        "Version"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ProfileReleased'
        QtMocHelpers::SignalData<void(uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Slot 'HoldProfile'
        QtMocHelpers::SlotData<QDBusPendingReply<uint>(const QString &, const QString &, const QString &)>(4, 2, QMC::AccessPublic, 0x80000000 | 5, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'ReleaseProfile'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(9, 2, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::UInt, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Actions'
        QtMocHelpers::PropertyData<QStringList>(11, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'ActiveProfile'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'ActiveProfileHolds'
        QtMocHelpers::PropertyData<QList<QVariantMap>>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'PerformanceDegraded'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'PerformanceInhibited'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Profiles'
        QtMocHelpers::PropertyData<QList<QVariantMap>>(17, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Version'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopUPowerPowerProfilesInterface, qt_meta_tag_ZN42OrgFreedesktopUPowerPowerProfilesInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopUPowerPowerProfilesInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgFreedesktopUPowerPowerProfilesInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgFreedesktopUPowerPowerProfilesInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN42OrgFreedesktopUPowerPowerProfilesInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopUPowerPowerProfilesInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopUPowerPowerProfilesInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ProfileReleased((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 1: { QDBusPendingReply<uint> _r = _t->HoldProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->ReleaseProfile((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopUPowerPowerProfilesInterface::*)(uint )>(_a, &OrgFreedesktopUPowerPowerProfilesInterface::ProfileReleased, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->actions(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->activeProfile(); break;
        case 2: *reinterpret_cast<QList<QVariantMap>*>(_v) = _t->activeProfileHolds(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->performanceDegraded(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->performanceInhibited(); break;
        case 5: *reinterpret_cast<QList<QVariantMap>*>(_v) = _t->profiles(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->version(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setActiveProfile(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *OrgFreedesktopUPowerPowerProfilesInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopUPowerPowerProfilesInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN42OrgFreedesktopUPowerPowerProfilesInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopUPowerPowerProfilesInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopUPowerPowerProfilesInterface::ProfileReleased(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
