/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ScreenBrightness.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "screenbrightnessadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class ScreenBrightnessAdaptor
 */

ScreenBrightnessAdaptor::ScreenBrightnessAdaptor(PowerDevil::ScreenBrightnessAgent *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

ScreenBrightnessAdaptor::~ScreenBrightnessAdaptor()
{
    // destructor
}

QStringList ScreenBrightnessAdaptor::displaysDBusNames() const
{
    // get the value of property DisplaysDBusNames
    return qvariant_cast< QStringList >(parent()->property("DisplaysDBusNames"));
}

void ScreenBrightnessAdaptor::AdjustBrightnessRatio(double delta, uint flags)
{
    // handle method call org.kde.ScreenBrightness.AdjustBrightnessRatio
    parent()->AdjustBrightnessRatio(delta, flags);
}

void ScreenBrightnessAdaptor::AdjustBrightnessRatioWithContext(double delta, uint flags, const QString &source_client_context)
{
    // handle method call org.kde.ScreenBrightness.AdjustBrightnessRatioWithContext
    parent()->AdjustBrightnessRatioWithContext(delta, flags, source_client_context);
}

void ScreenBrightnessAdaptor::AdjustBrightnessStep(uint step_action, uint flags)
{
    // handle method call org.kde.ScreenBrightness.AdjustBrightnessStep
    parent()->AdjustBrightnessStep(step_action, flags);
}

void ScreenBrightnessAdaptor::AdjustBrightnessStepWithContext(uint step_action, uint flags, const QString &source_client_context)
{
    // handle method call org.kde.ScreenBrightness.AdjustBrightnessStepWithContext
    parent()->AdjustBrightnessStepWithContext(step_action, flags, source_client_context);
}


#include "moc_screenbrightnessadaptor.cpp"
